@@ -373,12 +373,6 @@ void CL_FinishMove (usercmd_t *cmd)
 
 	cmd->impulse = in_impulse;
 	in_impulse = 0;
-
-// send the ambient light level at the player's current position
-	cmd->lightlevel = (byte)cl_lightlevel->value;
-
-	if (((in_attack.state & 2) || (in_use.state & 2)))
-		send_packet_now = true;
 }
 
 /*
@@ -511,12 +505,7 @@ void CL_SendCmd (void)
 	}
 
 	SZ_Init (&buf, data, sizeof(data));
-
-	if (cmd->buttons && cl.cinematictime > 0 && !cl.attractloop 
-		&& cls.realtime - cl.cinematictime > 1000)
-	{	// skip the rest of the cinematic
-		SCR_FinishCinematic ();
-	}
+	SZ_SetName ( &buf, "CL_SendCmd", false );
 
 	// begin a client move command
 	MSG_WriteByte (&buf, clc_move);
