@@ -64,6 +64,7 @@ cvar_t	*cl_gun;
 cvar_t  *cl_brass;
 cvar_t  *cl_showPlayerNames;
 cvar_t	*cl_playtaunts;
+cvar_t	*cl_centerprint;
 
 cvar_t	*cl_paindist;
 cvar_t	*cl_explosiondist;
@@ -132,6 +133,9 @@ cvar_t  *cl_disbeamclr;
 cvar_t	*cl_IRC_connect_at_startup;
 cvar_t	*cl_IRC_server;
 
+//Stats
+cvar_t  *cl_stats_server;
+
 client_static_t	cls;
 client_state_t	cl;
 
@@ -1299,6 +1303,7 @@ byte *precache_model; // used for skin checking in alias models
 // ENV_CNT is map load, ENV_CNT+1 is first env map
 #define ENV_CNT (CS_PLAYERSKINS + MAX_CLIENTS * PLAYER_MULT)
 #define TEXTURE_CNT (ENV_CNT+13)
+#define SCRIPT_CNT (TEXTURE_CNT+999)
 
 static const char *env_suf[6] = {"rt", "bk", "lf", "ft", "up", "dn"};
 
@@ -1306,7 +1311,10 @@ void CL_RequestNextDownload (void)
 {
 	unsigned	map_checksum;		// for detecting cheater maps
 	char fn[MAX_OSPATH];
+	char map[MAX_OSPATH];
+	char script[MAX_OSPATH];
 	dmdl_t *pheader;
+	int i, j;
 
 	if (cls.state != ca_connected)
 		return;
@@ -1314,12 +1322,11 @@ void CL_RequestNextDownload (void)
 	if (!allow_download->value && precache_check < ENV_CNT)
 		precache_check = ENV_CNT;
 
-//ZOID
 	if (precache_check == CS_MODELS) { // confirm map
 		precache_check = CS_MODELS+2; // 0 isn't used
 		if (allow_download_maps->value)
 			if (!CL_CheckOrDownloadFile(cl.configstrings[CS_MODELS+1]))
-				return; // started a download
+				return; // started a download		
 	}
 
 redoSkins:;
@@ -1393,6 +1400,7 @@ redoSkins:;
 		}
 		precache_check = CS_SOUNDS;
 	}
+
 	if (precache_check >= CS_SOUNDS && precache_check < CS_SOUNDS+MAX_SOUNDS) {
 		if (allow_download_sounds->value) {
 			if (precache_check == CS_SOUNDS)
@@ -1552,6 +1560,63 @@ redoSkins:;
 		precache_check = TEXTURE_CNT+999;
 	}
 
+	//get map related scripts
+	if (precache_check == SCRIPT_CNT) { 
+		precache_check = SCRIPT_CNT+1;
+		if (allow_download_maps->value) {			
+
+			//get fog files
+			COM_StripExtension ( cl.configstrings[CS_MODELS+1], fn );
+
+			//remove "maps/" from string
+			for(i = 5, j = 0; i < strlen(fn); i++, j++) {
+				map[j] = fn[i];
+			}
+			map[i-5] = 0;
+
+			Com_sprintf(script, sizeof(script), "maps/scripts/%s.fog", map);
+			if (!CL_CheckOrDownloadFile(script))
+				return; // started a download
+		}		
+	}
+
+	if (precache_check == SCRIPT_CNT+1) { 
+		precache_check = SCRIPT_CNT+2;
+		if (allow_download_maps->value) {			
+
+			//get mus files
+			COM_StripExtension ( cl.configstrings[CS_MODELS+1], fn );
+
+			//remove "maps/" from string
+			for(i = 5, j = 0; i < strlen(fn); i++, j++) {
+				map[j] = fn[i];
+			}
+			map[i-5] = 0;
+
+			Com_sprintf(script, sizeof(script), "maps/scripts/%s.mus", map);
+			if (!CL_CheckOrDownloadFile(script))
+				return; // started a download
+		}		
+	}
+
+	if (precache_check == SCRIPT_CNT+2) { 
+		precache_check = SCRIPT_CNT+3;
+		if (allow_download_maps->value) {						
+			//get rscript files
+			COM_StripExtension ( cl.configstrings[CS_MODELS+1], fn );
+
+			//remove "maps/" from string
+			for(i = 5, j = 0; i < strlen(fn); i++, j++) {
+				map[j] = fn[i];
+			}
+			map[i-5] = 0;
+
+			Com_sprintf(script, sizeof(script), "scripts/maps/%s.rscript", map);
+			if (!CL_CheckOrDownloadFile(script))
+				return; // started a download
+		}		
+	}
+
 //ZOID
 	CL_RegisterSounds ();
 	CL_PrepRefresh ();
@@ -1620,7 +1685,7 @@ void CL_InitLocal (void)
 	CL_InitHttpDownload();
 
 	cl_IRC_connect_at_startup = Cvar_Get("cl_IRC_connect_at_startup", "1", CVAR_ARCHIVE);
-	cl_IRC_server = Cvar_Get("cl_IRC_server", "irc.prison.net", CVAR_ARCHIVE);
+	cl_IRC_server = Cvar_Get("cl_IRC_server", "irc.efnet.org", CVAR_ARCHIVE);
 
 	if(cl_IRC_connect_at_startup->value)
 		CL_InitIRC();
@@ -1659,6 +1724,7 @@ void CL_InitLocal (void)
 	cl_disbeamclr = Cvar_Get("cl_disbeamclr", "0", CVAR_ARCHIVE);
 	cl_brass = Cvar_Get ("cl_brass", "1", CVAR_ARCHIVE);
 	cl_playtaunts = Cvar_Get ("cl_playtaunts", "1", CVAR_ARCHIVE);
+	cl_centerprint = Cvar_Get ("cl_centerprint", "1", CVAR_ARCHIVE);
 
 	cl_paindist = Cvar_Get ("cl_paindist", "1", CVAR_ARCHIVE);
 	cl_explosiondist = Cvar_Get ("cl_explosiondist", "1", CVAR_ARCHIVE);
@@ -1716,6 +1782,9 @@ void CL_InitLocal (void)
 	cl_hudimage1 = Cvar_Get("cl_hudimage1", "pics/i_health.tga", CVAR_ARCHIVE);
 	cl_hudimage2 = Cvar_Get("cl_hudimage2", "pics/i_score.tga", CVAR_ARCHIVE);
 
+	//stats server
+	cl_stats_server = Cvar_Get("cl_stats_server", "http://stats.planetarena.org", CVAR_ARCHIVE);
+
 	//
 	// register our commands
 	//
@@ -2116,6 +2185,8 @@ void CL_Shutdown(void)
 	IN_Shutdown ();
 	VID_Shutdown();	
 
+	NET_Shutdown();
+
 	RS_FreeAllScripts();
 }
 
