@@ -202,6 +202,9 @@ void SCR_CenterPrint (char *str)
 {
 	char	*s;
 
+	if(!cl_centerprint->value)
+		return;
+
 	strncpy (scr_centerstring, str, sizeof(scr_centerstring)-1);
 	scr_centertime_off = scr_centertime->value;
 	scr_centertime_start = cl.time;
@@ -252,7 +255,7 @@ void SCR_DrawCenterString (void)
 		SCR_AddDirtyPoint (x, y);
 		for (j=0 ; j<l ; j++, x+=charscale)
 		{
-			Draw_ScaledChar (x, y, start[j], charscale);
+			Draw_ScaledChar (x, y, start[j], charscale, false);
 			if (!remaining--)
 				return;
 		}
@@ -356,7 +359,7 @@ void SCR_DrawColorString ( int x, int y, const char *str )
 			continue;
 		}
 		
-		Draw_ScaledColorChar (x, y, *str, scolor, charscale); //this is only ever used for names.
+		Draw_ScaledColorChar (x, y, *str, scolor, charscale, false); //this is only ever used for names.
 		
 		num = *str++;
 		num &= 255;
@@ -1625,7 +1628,10 @@ void SCR_ExecuteLayoutString (char *s)
 		if (!strcmp(token, "string"))
 		{
 			token = COM_Parse (&s);
-			DrawString (x, y, token);
+			//this line is an Alien Arena specific hack of sorts, remove if needed
+			if(!strcmp(token, "Vote"))
+				Draw_ScaledPic (viddef.width/2 - 85*scale, y-8*scale, scale, "votebox");
+			DrawString (x, y, token);			
 			continue;
 		}
 
@@ -1726,8 +1732,7 @@ void SCR_DrawPlayerIcon(void) {
 	h*=scale;
 
 	Draw_AlphaStretchPlayerIcon( -w+(w*iconPos), viddef.height/2 + h/2, w, h, scr_playericon, scr_playericonalpha);
-	Menu_DrawColorString(-w+(w*iconPos), viddef.height/2 + h + 32*scale, scr_playername);
-
+	SCR_DrawColorString ( -w+(w*iconPos), viddef.height/2 + h + 32*scale, scr_playername);
 }
 
 /*
