@@ -31,12 +31,21 @@ struct model_s	*gun_model;
 int r_numflares;
 flare_t r_flares[MAX_FLARES];
 
+int r_numgrasses;
+grass_t r_grasses[MAX_GRASSES];
+
+int r_numbeams;
+beam_t	r_beams[MAX_BEAMS];
+
+qboolean need_free_vbo;
+
 //=============
 extern cvar_t *cl_showPlayerNames;
 extern cvar_t *name;
 extern char map_music[128];
 extern cvar_t *background_music;
 extern qboolean IsVisible(vec3_t org1,vec3_t org2);
+extern void R_VCFreeFrame(void);
 
 cvar_t		*crosshair;
 cvar_t		*cl_testparticles;
@@ -50,12 +59,12 @@ cvar_t		*cl_stats;
 int			r_numdlights;
 dlight_t	r_dlights[MAX_DLIGHTS];
 
-int			r_numstains;
-stain_t		r_stains[MAX_STAINS];
-
 int			r_numentities;
 entity_t	r_entities[MAX_ENTITIES];
 
+int			r_numviewentities;
+entity_t	r_viewentities[MAX_ENTITIES];
+
 int			r_numparticles;
 particle_t	r_particles[MAX_PARTICLES];
 
@@ -74,8 +83,8 @@ Specifies the model that will be used as the world
 void V_ClearScene (void)
 {
 	r_numdlights = 0;
-	r_numstains = 0;
 	r_numentities = 0;
+	r_numviewentities = 0;
 	r_numparticles = 0;
 }
 
@@ -93,6 +102,19 @@ void V_AddEntity (entity_t *ent)
 	r_entities[r_numentities++] = *ent;
 }
 
+/*
+=====================
+V_AddViewEntity
+
+=====================
+*/
+void V_AddViewEntity (entity_t *ent)
+{
+	if (r_numviewentities >= MAX_ENTITIES)
+		return;
+	r_viewentities[r_numviewentities++] = *ent;
+}
+
 
 /*
 =====================
@@ -158,26 +180,6 @@ void V_AddTeamLight (vec3_t org, float intensity, float r, float g, float b, int
 	dl->color[2] = b;
 	dl->team = team;
 }
-/*
-=====================
-V_AddStain
-
-=====================
-*/
-void V_AddStain (vec3_t org, float intensity, float r, float g, float b, float a)
-{
-	stain_t		*st;
-
-	if (r_numstains >= MAX_STAINS)
-		return;
-	st = &r_stains[r_numstains++];
-	VectorCopy (org, st->origin);
-	st->intensity = intensity;
-	st->color[0] = r;
-	st->color[1] = g;
-	st->color[2] = b;
-	st->alpha = a;
-}
 
 /*
 =====================
@@ -304,6 +306,7 @@ Call before entering a new level, or after changing dlls
 =================
 */
 qboolean needLoadingPlaque (void);
+extern int	seconds, minutes;
 void CL_PrepRefresh ()
 {
 	char		mapname[32];
@@ -341,6 +344,9 @@ void CL_PrepRefresh ()
 
 	numitemicons = 0;
 
+	//reset clock
+	seconds = minutes = 0;
+
 	if (!cl.configstrings[CS_MODELS+1][0])
 		return;		// no map loaded
     
@@ -517,8 +523,7 @@ void CL_PrepRefresh ()
 
 	// start background music
 	background_music = Cvar_Get ("background_music", "1", CVAR_ARCHIVE);
-	if(background_music->value)
-		S_StartMusic(map_music);
+	S_StartMapMusic();
 
 	//loadingMessage = false;
 	rocketlauncher = 0;
@@ -567,47 +572,12 @@ float CalcFov (float fov_x, float width, float height)
 		Com_Error (ERR_DROP, "Bad fov: %f", fov_x);
 
 	x = width/tan(fov_x/360*M_PI);
-
-	a = atan (height/x);
-
-	a = a*360/M_PI;
+    a = atan (height/x);   
+    a = a*360/M_PI; 
 
 	return a;
 }
 
-//============================================================================
-
-// gun frame debugging functions
-void V_Gun_Next_f (void)
-{
-	gun_frame++;
-	Com_Printf ("frame %i\n", gun_frame);
-}
-
-void V_Gun_Prev_f (void)
-{
-	gun_frame--;
-	if (gun_frame < 0)
-		gun_frame = 0;
-	Com_Printf ("frame %i\n", gun_frame);
-}
-
-void V_Gun_Model_f (void)
-{
-	char	name[MAX_QPATH];
-
-	if (Cmd_Argc() != 2)
-	{
-		gun_model = NULL;
-		return;
-	}
-	Com_sprintf (name, sizeof(name), "models/%s/tris.md2", Cmd_Argv(1));
-	gun_model = R_RegisterModel (name);
-}
-
-//============================================================================
-
-
 /*
 =================
 SCR_DrawCrosshair
@@ -647,10 +617,10 @@ qboolean InFront (vec3_t target)
 	return false;
 }
 //============== 
-//SCR_DrawPlayerNames 
-// shows player names at their feets. 
+//SCR_DrawPlayerNamesCenter
+// shows player names at center of screen 
 //============== 
-void SCR_DrawPlayerNames( void ) 
+void SCR_DrawPlayerNamesCenter( void ) 
 { 
    int         i; 
    centity_t   *cent; 
@@ -705,10 +675,96 @@ void SCR_DrawPlayerNames( void )
 
 	  }
 	  if(closest)
-		  Draw_ColorString( (int)(cl.refdef.width/2 - strlen(cl.clientinfo[closest].name)*3), (int)(cl.refdef.height/1.8), cl.clientinfo[closest].name);
+		  Draw_ColorString( (int)(cl.refdef.width/2 - strlen(cl.clientinfo[closest].name)*3), (int)(cl.refdef.height/1.8), cl.clientinfo[closest].name, 1);
   		
 }
 
+//============== 
+//SCR_DrawPlayerNames 
+// shows player names at their feets. 
+//============== 
+extern void R_TransformVectorToScreen( refdef_t *rd, vec3_t in, vec2_t out );
+void SCR_DrawPlayerNames( void ) 
+{ 
+   static vec4_t   whiteTransparent = { 1.0f, 1.0f, 1.0f, 0.5f }; 
+   int         i; 
+   centity_t   *cent; 
+   float      dist; 
+   trace_t   trace;
+   vec2_t screen_pos; 
+   vec3_t vecdist; 
+   vec3_t temp; 
+   vec3_t axis[3]; 
+   int y; 
+   static vec3_t mins = { -4, -4, -4 }; 
+   static vec3_t maxs = { 4, 4, 4 }; 
+
+   if( !cl_showPlayerNames->integer ) 
+      return; 
+  
+   for( i = 0; i < MAX_CLIENTS; i++ ) 
+   { 
+      
+	  cent = cl_entities + i + 1; 
+	
+	  if( !cent->current.modelindex ) 
+		 continue; 
+	 
+	  if(!strcmp(cl.clientinfo[i].name, name->string))
+		  continue;
+	
+	  trace = CL_Trace ( cl.refdef.vieworg, mins, maxs, cent->current.origin, -1, MASK_PLAYERSOLID, true, NULL); 
+	  if (trace.fraction != 1.0)	
+		  continue;
+
+	  VectorSubtract(cent->current.origin, cl.refdef.vieworg, vecdist); 
+	  dist = VectorLength(vecdist); 
+
+	  if (dist >= 1000 || !InFront(cent->current.origin)) 
+		  continue; 
+      
+	  VectorSubtract (cent->current.origin, cl.refdef.vieworg, temp); 
+	  VectorNormalize (temp); 
+
+	  AngleVectors(cl.refdef.viewangles, axis[0], axis[1], axis[2]); 
+
+	  if (DotProduct (temp, axis[0]) < 0) 
+	      continue; 
+
+	  R_TransformVectorToScreen(&cl.refdef, cent->current.origin, screen_pos); 
+	  y = cl.refdef.height-(int)screen_pos[1]-cl.refdef.height/6; 
+	  Draw_ColorString ( (int)screen_pos[0], y, cl.clientinfo[i].name, 1 ); 
+
+   } 
+}
+
+void SCR_DrawBases (void)
+{
+	int			i;
+	entity_t	*ent;
+    vec2_t screen_pos; 
+    int y; 
+
+	for (i=0 ; i<cl.refdef.num_entities; i++)
+	{
+		ent = &r_entities[i];
+
+		if(!ent->team)
+			continue;
+
+		if (!InFront(ent->origin)) 
+			continue; 
+    
+		R_TransformVectorToScreen(&cl.refdef, ent->origin, screen_pos); 
+		y = cl.refdef.height-(int)screen_pos[1]-cl.refdef.height/6; 
+		if(ent->team == 2)
+			Draw_ColorString ( (int)screen_pos[0], y, "^4Blue Flag", 1 ); 
+		else if(ent->team == 1)
+			Draw_ColorString ( (int)screen_pos[0], y, "^1Red Flag", 1 );
+
+	}
+}
+
 /*
 ==================
 V_RenderView
@@ -782,8 +838,10 @@ void V_RenderView( float stereo_separation )
 
 		cl.refdef.areabits = cl.frame.areabits;
 
-		if (!cl_add_entities->value)
+		if (!cl_add_entities->value) {
 			r_numentities = 0;
+			r_numviewentities = 0;
+		}
 		if (!cl_add_particles->value)
 			r_numparticles = 0;
 		if (!cl_add_lights->value)
@@ -795,15 +853,19 @@ void V_RenderView( float stereo_separation )
 
 		cl.refdef.num_entities = r_numentities;
 		cl.refdef.entities = r_entities;
+		cl.refdef.num_viewentities = r_numviewentities;
+		cl.refdef.viewentities = r_viewentities;
 		cl.refdef.num_particles = r_numparticles;
 		cl.refdef.particles = r_particles;
 		cl.refdef.num_dlights = r_numdlights;
 		cl.refdef.dlights = r_dlights;
-		cl.refdef.num_stains = r_numstains;
-		cl.refdef.stains = r_stains;
 		cl.refdef.lightstyles = r_lightstyles;
 		cl.refdef.num_flares = r_numflares;
         cl.refdef.flares = r_flares;
+		cl.refdef.num_grasses = r_numgrasses;
+		cl.refdef.grasses = r_grasses;
+		cl.refdef.num_beams = r_numbeams;
+		cl.refdef.beams = r_beams;
 
 		cl.refdef.rdflags = cl.frame.playerstate.rdflags;
 
@@ -815,6 +877,9 @@ void V_RenderView( float stereo_separation )
 
 	cl.refdef.rdflags |= RDF_BLOOM;   //BLOOMS
 
+	R_VCFreeFrame();
+	need_free_vbo = false;
+
 	R_RenderFrame (&cl.refdef);
 	if (cl_stats->value)
 		Com_Printf ("ent:%i  lt:%i  part:%i\n", r_numentities, r_numdlights, r_numparticles);
@@ -828,8 +893,14 @@ void V_RenderView( float stereo_separation )
 
 	SCR_DrawCrosshair ();
 
-	//JD - player names
-	SCR_DrawPlayerNames();
+	if(cl_showPlayerNames->integer) {
+		if(cl_showPlayerNames->integer == 2)
+			SCR_DrawPlayerNames();
+		else
+			SCR_DrawPlayerNamesCenter();
+
+		SCR_DrawBases();
+	}
 }
 
 
@@ -852,10 +923,6 @@ V_Init
 */
 void V_Init (void)
 {
-	Cmd_AddCommand ("gun_next", V_Gun_Next_f);
-	Cmd_AddCommand ("gun_prev", V_Gun_Prev_f);
-	Cmd_AddCommand ("gun_model", V_Gun_Model_f);
-
 	Cmd_AddCommand ("viewpos", V_Viewpos_f);
 
 	crosshair = Cvar_Get ("crosshair", "0", CVAR_ARCHIVE);
