@@ -40,8 +40,6 @@ extern	float		scr_conlines;		// lines of console to display
 
 extern	int			sb_lines;
 
-extern	cvar_t		*scr_viewsize;
-
 extern	cvar_t		*crosshair;
 extern	cvar_t		*cl_hudimage1;
 extern	cvar_t		*cl_hudimage2;
@@ -54,12 +52,4 @@ extern	int			crosshair_width, crosshair_height;
 void SCR_AddDirtyPoint (int x, int y);
 void SCR_DirtyScreen (void);
 
-//
-// scr_cin.c
-//
-void SCR_PlayCinematic (char *name);
-qboolean SCR_DrawCinematic (void);
-void SCR_RunCinematic (void);
-void SCR_StopCinematic (void);
-void SCR_FinishCinematic (void);
 
