@@ -269,14 +269,15 @@ void     ACEND_LoadNodes();
 // acebot_spawn.c protos
 void	 ACESP_SaveBots();
 void	 ACESP_LoadBots(edict_t *ent, int playerleft); 
+int		 ACESP_FindBotNum(void);
 int		 ACESP_FindBot(char *name);
 void	 ACESP_KickBot(char *name);
 void     ACESP_HoldSpawn(edict_t *self);
 void     ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team);
 void     ACESP_Respawn (edict_t *self);
 edict_t *ACESP_FindFreeClient (void);
-void     ACESP_SetName(edict_t *bot, char *name, char *skin, char *team);
-void     ACESP_SpawnBot (char *team, char *name, char *skin, char *userinfo);
+void     ACESP_SetName(edict_t *bot, char *name, char *skin);
+void     ACESP_SpawnBot (char *name, char *skin, char *userinfo);
 void     ACESP_ReAddBots();
 void     ACESP_RemoveBot(char *name);
 void	 safe_cprintf (edict_t *ent, int printlevel, char *fmt, ...);
