@@ -333,6 +333,7 @@ void plat_Accelerate (moveinfo_t *moveinfo)
 
 void Think_AccelMove (edict_t *ent)
 {
+
 	ent->moveinfo.remaining_distance -= ent->moveinfo.current_speed;
 
 	if (ent->moveinfo.current_speed == 0)		// starting or blocked
@@ -410,9 +411,7 @@ void plat_blocked (edict_t *self, edict_t *other)
 	{
 		// give it a chance to go away on it's own terms (like gibs)
 		T_Damage (other, self, self, vec3_origin, other->s.origin, vec3_origin, 100000, 1, 0, MOD_CRUSH);
-		// if it's still there, nuke it
-		if (other)
-			BecomeExplosion1 (other);
+	
 		return;
 	}
 
@@ -622,7 +621,7 @@ void rotating_use (edict_t *self, edict_t *other, edict_t *activator)
 
 void SP_func_rotating (edict_t *ent)
 {
-	ent->solid = SOLID_BSP;
+
 	if (ent->spawnflags & 32)
 		ent->movetype = MOVETYPE_STOP;
 	else
@@ -655,10 +654,13 @@ void SP_func_rotating (edict_t *ent)
 	if (ent->spawnflags & 1)
 		ent->use (ent, NULL, NULL);
 
-	if (ent->spawnflags & 64)
-		ent->s.effects |= EF_ANIM_ALL;
-	if (ent->spawnflags & 128)
-		ent->s.effects |= EF_ANIM_ALLFAST;
+	if(ent->spawnflags & 64)
+		ent->solid = SOLID_NOT;
+	else
+		ent->solid = SOLID_BSP;
+
+	if(!(ent->spawnflags & 128))
+		ent->s.renderfx = (RF_NOSHADOWS | RF_MINLIGHT); 
 
 	gi.setmodel (ent, ent->model);
 	gi.linkentity (ent);
@@ -742,6 +744,11 @@ void button_use (edict_t *self, edict_t *other, edict_t *activator)
 
 void button_touch (edict_t *self, edict_t *other, cplane_t *plane, csurface_t *surf)
 {
+
+	//do not allow buttons to be activated in warmup
+	if(level.time <= warmuptime->value) 
+		return;
+
 	if (!other->client)
 		return;
 
@@ -750,6 +757,12 @@ void button_touch (edict_t *self, edict_t *other, cplane_t *plane, csurface_t *s
 
 	self->activator = other;
 	button_fire (self);
+
+	//button pusher is immune to death rays - use spawn flags
+	if(self->spawnflags & 1) {
+		other->client->rayImmunity = true;
+		other->client->rayTime = level.time;
+	}
 }
 
 void button_killed (edict_t *self, edict_t *inflictor, edict_t *attacker, int damage, vec3_t point)
@@ -1081,9 +1094,7 @@ void door_blocked  (edict_t *self, edict_t *other)
 	{
 		// give it a chance to go away on it's own terms (like gibs)
 		T_Damage (other, self, self, vec3_origin, other->s.origin, vec3_origin, 100000, 1, 0, MOD_CRUSH);
-		// if it's still there, nuke it
-		if (other)
-			BecomeExplosion1 (other);
+		
 		return;
 	}
 
@@ -1464,9 +1475,7 @@ void train_blocked (edict_t *self, edict_t *other)
 	{
 		// give it a chance to go away on it's own terms (like gibs)
 		T_Damage (other, self, self, vec3_origin, other->s.origin, vec3_origin, 100000, 1, 0, MOD_CRUSH);
-		// if it's still there, nuke it
-		if (other)
-			BecomeExplosion1 (other);
+		
 		return;
 	}
 
@@ -1481,6 +1490,7 @@ void train_blocked (edict_t *self, edict_t *other)
 
 void train_wait (edict_t *self)
 {
+
 	if (self->target_ent->pathtarget)
 	{
 		char	*savetarget;
@@ -1534,6 +1544,7 @@ void train_next (edict_t *self)
 
 	first = true;
 again:
+
 	if (!self->target)
 	{
 //		gi.dprintf ("train_next: no next target\n");
@@ -1572,7 +1583,10 @@ again:
 	{
 		if (self->moveinfo.sound_start)
 			gi.sound (self, CHAN_NO_PHS_ADD+CHAN_VOICE, self->moveinfo.sound_start, 1, ATTN_STATIC, 0);
-		self->s.sound = gi.soundindex ("world/turbine1.wav");
+		if(self->spawnflags & 64)
+			self->s.sound = gi.soundindex("world/electricity.wav");
+		else
+			self->s.sound = gi.soundindex ("world/turbine1.wav");
 	}
 
 	VectorSubtract (ent->s.origin, self->mins, dest);
@@ -1580,8 +1594,7 @@ again:
 	VectorCopy (self->s.origin, self->moveinfo.start_origin);
 	VectorCopy (dest, self->moveinfo.end_origin);
 	Move_Calc (self, dest, train_wait);
-	VectorCopy (ent->s.angles, self->s.angles);//will this still work for regular trains?? hmmm
-	self->s.frame = (self->s.frame + 1) % 21;//for leader ship, etc
+	VectorCopy (ent->s.angles, self->s.angles);
 	self->spawnflags |= TRAIN_START_ON;
 }
 
@@ -1659,6 +1672,7 @@ void train_use (edict_t *self, edict_t *other, edict_t *activator)
 
 void SP_func_train (edict_t *self)
 {
+
 	self->movetype = MOVETYPE_PUSH;
 
 	VectorClear (self->s.angles);
@@ -1670,8 +1684,19 @@ void SP_func_train (edict_t *self)
 		if (!self->dmg)
 			self->dmg = 100;
 	}
-	self->solid = SOLID_BSP;
+	if(self->spawnflags & 8)
+		self->solid = SOLID_NOT;
+	else
+		self->solid = SOLID_BSP;
 	gi.setmodel (self, self->model);
+	self->s.frame = 0; //in case of mesh
+	if(self->spawnflags & 16)
+		self->s.renderfx = RF_TRANSLUCENT;
+
+	self->s.renderfx |= RF_NOSHADOWS; //just too unpredictable and odd
+
+	if(self->spawnflags & 64)
+		self->s.effects |= EF_HYPERBLASTER; //teleporter type effect
 
 	self->moveinfo.sound_middle = gi.soundindex ("world/turbine1.wav");
 
@@ -2051,3 +2076,5 @@ void SP_func_killbox (edict_t *ent)
 	ent->svflags = SVF_NOCLIENT;
 }
 
+
+
