@@ -485,6 +485,9 @@ extern	int red_team_cnt;
 extern  int blue_team_cnt;
 extern  int red_team_score;
 extern  int blue_team_score;
+extern  int reddiff;
+extern	int bluediff;
+extern	int redwinning;
 extern	int print1;
 extern  int print2;
 extern  int print3;
@@ -1093,6 +1096,9 @@ typedef struct
 	int reward_pts;
 	qboolean powered;
 
+	//homing rocket limits
+	int	homing_shots;
+
 	//voting
 	qboolean voted;
 
@@ -1509,6 +1515,19 @@ extern void DeathcamRemove (edict_t *ent, char *opt);
 extern void DeathcamStart (edict_t *ent);
 extern void DeathcamTrack (edict_t *ent);
 
+//IP information
+typedef struct
+{
+	unsigned	mask;
+	unsigned	compare;
+} ipfilter_t;
+
+#define	MAX_IPFILTERS	1024
+
+ipfilter_t	ipfilters[MAX_IPFILTERS];
+int			numipfilters;
+extern qboolean StringToFilter (char *s, ipfilter_t *f);
+
 //unlagged
 extern	cvar_t	*g_antilag;
 extern  cvar_t	*g_antilagdebug;
