@@ -1012,150 +1012,6 @@ void SP_misc_teleporter_dest (edict_t *ent)
 	gi.linkentity (ent);
 }
 
-void SP_misc_etube (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_BBOX;
-
-	
-	ent->s.modelindex = gi.modelindex ("models/misc/tube/tris.md2"); 
-	ent->s.modelindex2 = gi.modelindex ("models/misc/tube/cover.md2");
-
-	ent->s.effects = EF_COLOR_SHELL;
-
-	ent->s.renderfx = (RF_SHELL_BLUE | RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-	VectorSet (ent->mins, -16, -16, 0);
-	VectorSet (ent->maxs, 16, 16, 64);
-
-	ent->s.frame = 0;
-	gi.linkentity (ent);
-
-	ent->think = NULL;
-}
-void misc_receptor_think (edict_t *ent)
-{
-	ent->s.frame = (ent->s.frame + 1) % 13;
-	ent->nextthink = level.time + FRAMETIME;
-}
-
-void SP_misc_receptor (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_NOT;
-	ent->s.modelindex = gi.modelindex ("models/misc/receptor/tris.md2");
-	ent->s.modelindex2 = gi.modelindex ("models/misc/receptor/bulb.md2");
-
-	ent->solid = SOLID_BBOX;
-	ent->s.effects = EF_COLOR_SHELL;
-
-	ent->s.renderfx = (RF_SHELL_BLUE | RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-
-	VectorSet (ent->mins, -16, -16, 0);
-	VectorSet (ent->maxs, 16, 16, 48);
-
-	ent->s.frame = rand() % 13;
-	gi.linkentity (ent);
-
-	ent->think = misc_receptor_think;
-	ent->nextthink = level.time + FRAMETIME;
-}
-void SP_misc_lamp (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_NOT;
-	
-	ent->s.modelindex = gi.modelindex ("models/misc/lamp/tris.md2"); 
-	
-	ent->s.renderfx = (RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-	VectorSet (ent->mins, -8, -8, 0);
-	VectorSet (ent->maxs, 8, 8, 24);
-
-	ent->s.frame = 0;
-	gi.linkentity (ent);
-
-	ent->think = NULL;
-}
-void SP_misc_lamp2 (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_NOT;
-
-	
-	ent->s.modelindex = gi.modelindex ("models/misc/lamp2/tris.md2"); 
-	
-	ent->s.renderfx = (RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-	VectorSet (ent->mins, -8, -8, 0);
-	VectorSet (ent->maxs, 8, 8, 56);
-	
-	ent->health = 50;
-	ent->die = barrel_delay;
-	ent->takedamage = DAMAGE_YES;
-	
-	ent->s.frame = 0;
-	gi.linkentity (ent);
-
-	ent->think = NULL;
-}
-void SP_misc_electrode (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_BBOX;
-
-	
-	ent->s.modelindex = gi.modelindex ("models/misc/electrode/tris.md2"); 
-	ent->s.modelindex2 = gi.modelindex ("models/misc/electrode/cover.md2");
-
-	ent->s.renderfx = (RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-	VectorSet (ent->mins, -16, -16, 0);
-	VectorSet (ent->maxs, 16, 16, 64);
-
-	ent->health = 50;
-	ent->die = barrel_delay;
-	ent->takedamage = DAMAGE_YES;
-
-	ent->s.frame = 0;
-	gi.linkentity (ent);
-
-	ent->think = NULL;
-}
-void SP_misc_scope (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_BBOX;
-
-	
-	ent->s.modelindex = gi.modelindex ("models/misc/scope/tris.md2"); 
-	ent->s.modelindex2 = gi.modelindex ("models/misc/scope/cover.md2");
-
-	ent->s.renderfx = (RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-	VectorSet (ent->mins, -32, -32, 0);
-	VectorSet (ent->maxs, 32, 32, 128);
-
-	ent->health = 500;
-	ent->die = barrel_delay;
-	ent->takedamage = DAMAGE_YES;
-
-	ent->s.frame = 0;
-	gi.linkentity (ent);
-
-	ent->think = NULL;
-}
-void SP_misc_pod (edict_t *ent)
-{
-	ent->movetype = MOVETYPE_NONE;
-	ent->solid = SOLID_BBOX;
-	
-	ent->s.modelindex = gi.modelindex ("models/misc/pod/tris.md2"); 
-	
-	ent->s.renderfx = (RF_FULLBRIGHT | RF_GLOW | RF_NOSHADOWS);
-	VectorSet (ent->mins, -16, -16, 0);
-	VectorSet (ent->maxs, 16, 16, 64);
-
-	ent->s.frame = 0;
-	gi.linkentity (ent);
-
-	ent->think = NULL;
-}
 void spidervolts (edict_t *self)
 {
 	
@@ -1483,12 +1339,68 @@ void SP_misc_bluespidernode (edict_t *ent)
 	M_droptofloor (ent);
 }
 
+void misc_mapmodel_think (edict_t *ent)
+{
+	ent->s.frame = (ent->s.frame + 1) % 24;
+	ent->nextthink = level.time + FRAMETIME;
+}
 void SP_misc_mapmodel (edict_t *ent) //random .md2 map models
 {
 	gi.setmodel (ent, ent->model);
 
 	ent->solid = SOLID_NOT; //will need clipping brushes around it
 
-	gi.linkentity (ent);
+	//disable shadows(also disables per-pixel dynamic lighting unless minlight set
+	if(ent->spawnflags & 1) 
+		ent->s.renderfx = RF_NOSHADOWS;
+
+	if(ent->spawnflags & 16)
+		ent->s.renderfx = RF_TRANSLUCENT;
+
+	if(ent->spawnflags & 32) { //animated mesh
+		ent->s.frame = rand()%24;
+		ent->think = misc_mapmodel_think;
+		ent->nextthink = level.time + FRAMETIME;
+	}
+	else //static mesh
+		ent->s.frame = 0;
+ 
+	//allow dynamic per-pixel lighting
+	if(ent->spawnflags & 64)
+		ent->s.renderfx |= RF_MINLIGHT;
 	
+	gi.linkentity (ent);	
+}
+
+void watersplash_think (edict_t *ent)
+{
+	vec3_t up;
+
+	up[0] = 0;
+	up[1] = 0;
+	up[2] = 1;
+
+	//write effect
+	gi.WriteByte (svc_temp_entity);
+	gi.WriteByte (TE_SPLASH);
+	gi.WriteByte (8);
+	gi.WritePosition (ent->s.origin);
+	gi.WriteDir (up);
+	gi.WriteByte (SPLASH_BLUE_WATER); //we should allow spawnflags to change this 
+	gi.multicast (ent->s.origin, MULTICAST_PVS);
+
+	ent->nextthink = level.time + 1.0;
+}
+
+void SP_misc_watersplash (edict_t *ent)
+{
+	gi.setmodel(ent, NULL);
+	ent->solid = SOLID_NOT;
+	ent->movetype = MOVETYPE_NONE;
+	ent->takedamage = DAMAGE_NO;
+
+	ent->think = watersplash_think;
+	ent->nextthink = level.time + 0.5 + random();
+
+	gi.linkentity (ent);
 }
\ No newline at end of file
