@@ -55,18 +55,16 @@ void SP_trigger_bluecowtarget (edict_t *ent);
 void SP_target_temp_entity (edict_t *ent);
 void SP_target_speaker (edict_t *ent);
 void SP_target_explosion (edict_t *ent);
-void SP_target_changelevel (edict_t *ent);
 void SP_target_secret (edict_t *ent);
 void SP_target_splash (edict_t *ent);
 void SP_target_steam (edict_t *ent);
 void SP_target_spawner (edict_t *ent);
 void SP_target_blaster (edict_t *ent);
-void SP_target_crosslevel_trigger (edict_t *ent);
-void SP_target_crosslevel_target (edict_t *ent);
 void SP_target_laser (edict_t *self);
 void SP_target_lightramp (edict_t *self);
 void SP_target_earthquake (edict_t *ent);
 void SP_target_fire (edict_t *ent);
+void SP_target_changelevel (edict_t *ent);
 
 void SP_worldspawn (edict_t *ent);
 
@@ -138,18 +136,16 @@ spawn_t	spawns[] = {
 	{"target_temp_entity", SP_target_temp_entity},
 	{"target_speaker", SP_target_speaker},
 	{"target_explosion", SP_target_explosion},
-	{"target_changelevel", SP_target_changelevel},
 	{"target_secret", SP_target_secret},
 	{"target_splash", SP_target_splash},
 	{"target_steam", SP_target_steam},
 	{"target_spawner", SP_target_spawner},
 	{"target_blaster", SP_target_blaster},
-	{"target_crosslevel_trigger", SP_target_crosslevel_trigger},
-	{"target_crosslevel_target", SP_target_crosslevel_target},
 	{"target_laser", SP_target_laser},
 	{"target_lightramp", SP_target_lightramp},
 	{"target_earthquake", SP_target_earthquake},
 	{"target_fire", SP_target_fire},
+	{"target_changelevel", SP_target_changelevel},
 
 	{"worldspawn", SP_worldspawn},
 
