@@ -87,10 +87,7 @@ void Use_Target_Speaker (edict_t *ent, edict_t *other, edict_t *activator)
 }
 void Target_Speaker_Think (edict_t *ent)
 {
-	if(!background_music->value) 
-		ent->s.sound = 0;
-	else
-		ent->s.sound = ent->noise_index;
+	ent->s.sound = ent->noise_index;
 
 	ent->nextthink = level.time + 1;	
 }
@@ -214,62 +211,6 @@ void SP_target_explosion (edict_t *ent)
 	ent->svflags = SVF_NOCLIENT;
 }
 
-
-//==========================================================
-
-/*QUAKED target_changelevel (1 0 0) (-8 -8 -8) (8 8 8)
-Changes level to "map" when fired
-*/
-void use_target_changelevel (edict_t *self, edict_t *other, edict_t *activator)
-{
-	if (level.intermissiontime)
-		return;		// already activated
-
-	if (!deathmatch->value)
-	{
-		if (g_edicts[1].health <= 0)
-			return;
-	}
-
-	// if noexit, do a ton of damage to other
-	if (deathmatch->value && !( (int)dmflags->value & DF_ALLOW_EXIT) && other != world)
-	{
-		T_Damage (other, self, self, vec3_origin, other->s.origin, vec3_origin, 10 * other->max_health, 1000, 0, MOD_EXIT);
-		return;
-	}
-
-	// if multiplayer, let everyone know who hit the exit
-	if (deathmatch->value)
-	{
-		if (activator && activator->client)
-			safe_bprintf (PRINT_HIGH, "%s exited the level.\n", activator->client->pers.netname);
-	}
-
-	// if going to a new unit, clear cross triggers
-	if (strstr(self->map, "*"))	
-		game.serverflags &= ~(SFL_CROSS_TRIGGER_MASK);
-
-	BeginIntermission (self);
-}
-
-void SP_target_changelevel (edict_t *ent)
-{
-	if (!ent->map)
-	{
-		gi.dprintf("target_changelevel with no map at %s\n", vtos(ent->s.origin));
-		G_FreeEdict (ent);
-		return;
-	}
-
-	// ugly hack because *SOMEBODY* screwed up their map
-   if((Q_stricmp(level.mapname, "fact1") == 0) && (Q_stricmp(ent->map, "fact3") == 0))
-	   ent->map = "fact3$secret1";
-
-	ent->use = use_target_changelevel;
-	ent->svflags = SVF_NOCLIENT;
-}
-
-
 //==========================================================
 
 /*QUAKED target_splash (1 0 0) (-8 -8 -8) (8 8 8)
@@ -441,49 +382,6 @@ void SP_target_blaster (edict_t *self)
 	self->svflags = SVF_NOCLIENT;
 }
 
-
-//==========================================================
-
-/*QUAKED target_crosslevel_trigger (.5 .5 .5) (-8 -8 -8) (8 8 8) trigger1 trigger2 trigger3 trigger4 trigger5 trigger6 trigger7 trigger8
-Once this trigger is touched/used, any trigger_crosslevel_target with the same trigger number is automatically used when a level is started within the same unit.  It is OK to check multiple triggers.  Message, delay, target, and killtarget also work.
-*/
-void trigger_crosslevel_trigger_use (edict_t *self, edict_t *other, edict_t *activator)
-{
-	game.serverflags |= self->spawnflags;
-	G_FreeEdict (self);
-}
-
-void SP_target_crosslevel_trigger (edict_t *self)
-{
-	self->svflags = SVF_NOCLIENT;
-	self->use = trigger_crosslevel_trigger_use;
-}
-
-/*QUAKED target_crosslevel_target (.5 .5 .5) (-8 -8 -8) (8 8 8) trigger1 trigger2 trigger3 trigger4 trigger5 trigger6 trigger7 trigger8
-Triggered by a trigger_crosslevel elsewhere within a unit.  If multiple triggers are checked, all must be true.  Delay, target and
-killtarget also work.
-
-"delay"		delay before using targets if the trigger has been activated (default 1)
-*/
-void target_crosslevel_target_think (edict_t *self)
-{
-	if (self->spawnflags == (game.serverflags & SFL_CROSS_TRIGGER_MASK & self->spawnflags))
-	{
-		G_UseTargets (self, self);
-		G_FreeEdict (self);
-	}
-}
-
-void SP_target_crosslevel_target (edict_t *self)
-{
-	if (! self->delay)
-		self->delay = 1;
-	self->svflags = SVF_NOCLIENT;
-
-	self->think = target_crosslevel_target_think;
-	self->nextthink = level.time + self->delay;
-}
-
 //==========================================================
 
 /*QUAKED target_laser (0 .5 .8) (-8 -8 -8) (8 8 8) START_ON RED GREEN BLUE YELLOW ORANGE FAT
@@ -680,6 +578,54 @@ void SP_target_laser (edict_t *self)
 	self->nextthink = level.time + 1;
 }
 
+/*QUAKED target_changelevel (1 0 0) (-8 -8 -8) (8 8 8)   
+Changes level to "map" when fired   
+*/   
+void use_target_changelevel (edict_t *self, edict_t *other, edict_t *activator)   
+{   
+	if (level.intermissiontime)   
+		return;         // already activated   
+     
+    if (!deathmatch->value)   
+    {   
+		if (g_edicts[1].health <= 0)   
+			return;   
+    }  
+     
+    // if noexit, do a ton of damage to other   
+    if (deathmatch->value && !( (int)dmflags->value & DF_ALLOW_EXIT) && other != world)   
+    {   
+		T_Damage (other, self, self, vec3_origin, other->s.origin, vec3_origin, 10 * other->max_health, 1000, 0, MOD_EXIT);   
+        return;   
+    }   
+     
+    // if multiplayer, let everyone know who hit the exit   
+    if (deathmatch->value)   
+    {   
+		if (activator && activator->client)   
+			safe_bprintf (PRINT_HIGH, "%s exited the level.\n", activator->client->pers.netname);   
+    } 
+     
+	// if going to a new unit, clear cross triggers   
+    if (strstr(self->map, "*"))   
+		game.serverflags &= ~(SFL_CROSS_TRIGGER_MASK);   
+     
+    BeginIntermission (self);   
+}   
+     
+void SP_target_changelevel (edict_t *ent)   
+{   
+	if (!ent->map)   
+    {   
+		gi.dprintf("target_changelevel with no map at %s\n", vtos(ent->s.origin));   
+        G_FreeEdict (ent);   
+        return;   
+    }   
+     
+    ent->use = use_target_changelevel;   
+    ent->svflags = SVF_NOCLIENT;   
+}  
+
 //==========================================================
 
 /*QUAKED target_lightramp (0 .5 .8) (-8 -8 -8) (8 8 8) TOGGLE
