@@ -71,8 +71,13 @@ typedef enum {false, true}	qboolean;
 #define	MAX_STRING_TOKENS	80		// max tokens resulting from Cmd_TokenizeString
 #define	MAX_TOKEN_CHARS		1024		// max length of an individual token
 
+#ifdef __unix__
+#define	MAX_QPATH			256		// max length of a quake game pathname
+#define	MAX_OSPATH			256		// max length of a filesystem pathname
+#else
 #define	MAX_QPATH			64		// max length of a quake game pathname
 #define	MAX_OSPATH			128		// max length of a filesystem pathname
+#endif
 
 //
 // per-level limits
@@ -634,13 +639,14 @@ typedef struct
 #define RF_SHELL_RED		1024
 #define	RF_SHELL_GREEN		2048
 #define RF_SHELL_BLUE		4096
-#define RF_IR_VISIBLE		0x00008000		// 32768
+#define RF_BOBBING			0x00008000		// 32768
 #define	RF_SHELL_DOUBLE		0x00010000		// 65536
 #define	RF_SHELL_HALF_DAM	0x00020000
 #define RF_NOSHADOWS		0x00040000 //use this one for turning off shadows, etc.
 #define RF_MONSTER  		0x00080000
 #define RF_MENUMODEL		0x01280000 //for player menu
 
+
 // player_state_t->refdef flags
 #define	RDF_UNDERWATER		1		// warp the screen as apropriate
 #define RDF_NOWORLDMODEL	2		// used for player configuration screen
