@@ -22,13 +22,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <setjmp.h>
 
-#define	MAXPRINTMSG	4096
+#define	MAXPRINTMSG	8192
 
 #define MAX_NUM_ARGVS	50
 
 #ifndef DEDICATED_ONLY
 extern void S_StartLocalSound (char *sound);
 extern void S_StartMusic ( char * sound );
+extern void S_StartMenuMusic( void );
 #endif
 
 extern void CL_Disconnect(void);
@@ -49,6 +50,7 @@ cvar_t	*developer;
 cvar_t	*timescale;
 cvar_t	*fixedtime;
 cvar_t	*logfile_active;	// 1 = buffer log, 2 = flush after each print
+cvar_t	*logfile_name;
 cvar_t	*showtrace;
 cvar_t	*dedicated;
 
@@ -111,7 +113,7 @@ void Com_Printf (char *fmt, ...)
 	char		msg[MAXPRINTMSG];
 
 	va_start (argptr,fmt);
-	vsprintf (msg,fmt,argptr);
+	vsnprintf(msg, sizeof(msg), fmt, argptr);
 	va_end (argptr);
 
 	if (rd_target)
@@ -135,23 +137,39 @@ void Com_Printf (char *fmt, ...)
 	Sys_Print(msg);
 #endif
 
+	// if logfile_active or logfile_name have been modified, close the current log file
+	if ( (logfile_active && logfile_active->modified || logfile_name && logfile_name->modified) && logfile ) {
+		fclose (logfile);
+		logfile = NULL;
+		if (logfile_active) {
+			logfile_active->modified = false;
+		}
+		if (logfile_name) {
+			logfile_name->modified = false;
+		}
+	}
+
 	// logfile
 	if (logfile_active && logfile_active->value)
 	{
-		char	name[MAX_QPATH];
+		char		name[MAX_QPATH];
+		const char 	*f_name;
 
 		if (!logfile)
 		{
-			Com_sprintf (name, sizeof(name), "%s/qconsole.log", FS_Gamedir ());
+			f_name = logfile_name ? logfile_name->string : "qconsole.log";
+			Com_sprintf (name, sizeof(name), "%s/%s", FS_Gamedir (), f_name);
+
 			if (logfile_active->value > 2)
 				logfile = fopen (name, "a");
 			else
 				logfile = fopen (name, "w");
 		}
-		if (logfile)
+		if (logfile) {
 			fprintf (logfile, "%s", msg);
-		if (logfile_active->value > 1)
-			fflush (logfile);		// force it to save every time
+			if (logfile_active->value > 1)
+				fflush (logfile);		// force it to save every time
+		}
 	}
 }
 
@@ -172,7 +190,7 @@ void Com_DPrintf (char *fmt, ...)
 		return;			// don't confuse non-developers with techie stuff...
 
 	va_start (argptr,fmt);
-	vsprintf (msg,fmt,argptr);
+	vsnprintf(msg, sizeof(msg), fmt, argptr);
 	va_end (argptr);
 
 	Com_Printf ("%s", msg);
@@ -191,14 +209,14 @@ void Com_Error (int code, char *fmt, ...)
 {
 	va_list		argptr;
 	static char		msg[MAXPRINTMSG];
-	static	qboolean	recursive;
+	static	qboolean	recursive = false;
 
 	if (recursive)
 		Sys_Error ("recursive error after: %s", msg);
 	recursive = true;
 
 	va_start (argptr,fmt);
-	vsprintf (msg,fmt,argptr);
+	vsnprintf(msg, sizeof(msg), fmt, argptr);
 	va_end (argptr);
 
 	if (code == ERR_DISCONNECT)
@@ -444,7 +462,7 @@ void MSG_WriteDeltaUsercmd (sizebuf_t *buf, usercmd_t *from, usercmd_t *cmd)
 void MSG_WriteDir (sizebuf_t *sb, vec3_t dir)
 {
 	int		i, best;
-	float	d, bestd;
+	float	d,x,y,z;
 
 	if (!dir)
 	{
@@ -452,17 +470,59 @@ void MSG_WriteDir (sizebuf_t *sb, vec3_t dir)
 		return;
 	}
 
-	bestd = 0;
+	x = dir[0];
+	y = dir[1];
+	z = dir[2];
 	best = 0;
-	for (i=0 ; i<NUMVERTEXNORMALS ; i++)
+	
+	d = (x*x) + (y*y) + (z*z);
+	// sometimes dir is {0,0,0}
+	if ( d == 0.0f )
 	{
-		d = DotProduct (dir, bytedirs[i]);
-		if (d > bestd)
-		{
-			bestd = d;
-			best = i;
+		MSG_WriteByte( sb, 0 );
+		return;
+	}
+	// sometimes dir is not normalized
+	if ( d < 0.999f || d > 1.001f )
+	{
+		d = 1.0 / sqrt( d );
+		x *= d;
+		y *= d;
+		z *= d;
+	}
+	// frequently occurring axial cases, use known best index
+	if ( x == 0.0f && y == 0.0f )
+	{
+		best = ( z >= 0.999f ) ? 5  : 84;
+	}
+	else if ( x == 0.0f && z == 0.0f )
+	{
+		best = ( y >= 0.999f ) ? 32 : 104;
+	}
+	else if ( y == 0.0f && z == 0.0f )
+	{
+		best = ( x >= 0.999f ) ? 52 : 143;
+	}
+	else
+	{ // general case
+		float bestd = 0.0f;
+		for ( i = 0 ; i < NUMVERTEXNORMALS ; i++ )
+		{ // search for closest match
+			d = (x*bytedirs[i][0]) + (y*bytedirs[i][1]) + (z*bytedirs[i][2]);
+			if ( d > 0.985f )
+			{ // no other entry could be a closer match
+				//  0.9679495 is max dot product between anorm.h entries
+				best = i;
+				break;
+			}
+			if ( d > bestd )
+			{
+				bestd = d;
+				best = i;
+			}
 		}
 	}
+
 	MSG_WriteByte (sb, best);
 }
 
@@ -899,11 +959,21 @@ void SZ_Init (sizebuf_t *buf, byte *data, int length)
 	buf->maxsize = length;
 }
 
+#ifdef	BUFFER_DEBUG
+void SZ_SetName(sizebuf_t * buf, const char * name, qboolean print_it)
+{
+	strncpy(buf->name, name, sizeof(buf->name) - 1);
+	if ( print_it )
+		Com_Printf("SZ_SetName: buffer '%s' (address = 0x%.12x) initialised\n", buf->name, buf);
+}
+#endif	//BUFFER_DEBUG
+
 void SZ_Clear (sizebuf_t *buf)
 {
 	buf->cursize = 0;
 	buf->overflowed = false;
 }
+
 void *SZ_GetSpace (sizebuf_t *buf, int length)
 {
 	void	*data;
@@ -916,7 +986,11 @@ void *SZ_GetSpace (sizebuf_t *buf, int length)
 		if (length > buf->maxsize)
 			Com_Error (ERR_FATAL, "SZ_GetSpace: %i is > full buffer size", length);
 
+#ifdef	BUFFER_DEBUG
+		Com_Printf ("SZ_GetSpace (%s at 0x%.12x): overflow\n", buf->name, buf);
+#else	//BUFFER_DEBUG
 		Com_Printf ("SZ_GetSpace: overflow\n");
+#endif	//BUFFER_DEBUG
 		SZ_Clear (buf);
 		buf->overflowed = true;
 	}
@@ -1461,6 +1535,7 @@ void Qcommon_Init (int argc, char **argv)
 	timescale = Cvar_Get ("timescale", "1", 0);
 	fixedtime = Cvar_Get ("fixedtime", "0", 0);
 	logfile_active = Cvar_Get ("logfile", "3", CVAR_ARCHIVE);
+	logfile_name = Cvar_Get ("logname", "qconsole.log", CVAR_ARCHIVE);
 	showtrace = Cvar_Get ("showtrace", "0", 0);
 #ifdef DEDICATED_ONLY
 	dedicated = Cvar_Get ("dedicated", "1", CVAR_NOSET);
@@ -1508,7 +1583,7 @@ void Qcommon_Init (int argc, char **argv)
 #ifndef DEDICATED_ONLY
 	//play music
 	if (!dedicated->value)
-		S_StartMusic("misc/menumusic.wav");
+		S_StartMenuMusic();
 #endif
 	Com_Printf ("======== CRX Initialized ========\n\n");
 }
