@@ -19,6 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "qcommon.h"
+#include "../unix/glob.h"
 
 // define this to dissalow any data but the demo pak file
 //#define	NO_ADDONS
@@ -150,46 +151,6 @@ void FS_FCloseFile (FILE *f)
 	fclose (f);
 }
 
-
-// RAFAEL
-/*
-	Developer_searchpath
-*/
-int	Developer_searchpath (int who)
-{
-
-	int		ch;
-	// PMM - warning removal
-//	char	*start;
-	searchpath_t	*search;
-
-	if (who == 1) // xatrix
-		ch = 'x';
-	else if (who == 2)
-		ch = 'r';
-
-	for (search = fs_searchpaths ; search ; search = search->next)
-	{
-		if (strstr (search->filename, "xatrix"))
-			return 1;
-
-		if (strstr (search->filename, "rogue"))
-			return 2;
-/*
-		start = strchr (search->filename, ch);
-
-		if (start == NULL)
-			continue;
-
-		if (strcmp (start ,"xatrix") == 0)
-			return (1);
-*/
-	}
-	return (0);
-
-}
-
-
 /*
 ===========
 FS_FOpenFile
@@ -613,21 +574,31 @@ Use ~/.codered/dir as fs_gamedir
 void FS_AddHomeAsGameDirectory (char *dir)
 {
 	char gdir[MAX_OSPATH];
-	char *homedir=getenv("HOME");
-	if(homedir)
+	char *homedir = getenv("COR_GAME");
+	int len;
+
+	if (homedir)
 	{
-		int len = snprintf(gdir,sizeof(gdir),"%s/.codered/%s/", homedir, dir);
-		Com_Printf("using %s for writing\n",gdir);
-		FS_CreatePath (gdir);
-
-		if ((len > 0) && (len < sizeof(gdir)) && (gdir[len-1] == '/'))
-			gdir[len-1] = 0;
-
-		strncpy(fs_gamedir,gdir,sizeof(fs_gamedir)-1);
-		fs_gamedir[sizeof(fs_gamedir)-1] = 0;
-
-		FS_AddGameDirectory (gdir);
+		len = snprintf (gdir, sizeof(gdir), "%s/%s/", homedir, dir);
 	}
+	else
+	{
+		homedir = getenv("HOME");
+		if (!homedir)
+			return;
+		len = snprintf(gdir,sizeof(gdir),"%s/.codered/%s/", homedir, dir);
+	}
+
+	Com_Printf("using %s for writing\n",gdir);
+	FS_CreatePath (gdir);
+
+	if ((len > 0) && (len < sizeof(gdir)) && (gdir[len-1] == '/'))
+		gdir[len-1] = 0;
+
+	strncpy(fs_gamedir,gdir,sizeof(fs_gamedir)-1);
+	fs_gamedir[sizeof(fs_gamedir)-1] = 0;
+
+	FS_AddGameDirectory (gdir);
  }
 #endif
 
