@@ -27,27 +27,74 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 
 image_t		*draw_chars;
+image_t		*menu_chars;
 
 extern	qboolean	scrap_dirty;
 extern  void GL_BlendFunction (GLenum sfactor, GLenum dfactor);
 extern cvar_t *con_font;
 void Scrap_Upload (void);
 
+//small dot used for failsafe blank texture
+byte	blanktexture[16][16] =
+{
+	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
+};
 
 void RefreshFont (void)
 {
+	int		x,y;
+	byte	data[16][16][4];
+
+	//
+	// tiny blank texture
+	//
+	for (x=0 ; x<16 ; x++)
+	{
+		for (y=0 ; y<16 ; y++)
+		{
+			data[y][x][0] = 255;
+			data[y][x][1] = 255;
+			data[y][x][2] = 255;
+			data[y][x][3] = blanktexture[x][y]; 
+		}
+	}
 
 	draw_chars = GL_FindImage (va("fonts/%s.tga", con_font->string), it_pic);
 	if (!draw_chars)
 	{
-		draw_chars = GL_FindImage ("pics/conchars.tga", it_pic);
+		draw_chars = GL_FindImage ("fonts/default.tga", it_pic);
 		Cvar_Set( "con_font", "default" );
+
+		if(!draw_chars)
+			draw_chars = GL_LoadPic ("***font***", (byte *)data, 16, 16, it_pic, 32);
 	}
 
 	GL_Bind( draw_chars->texnum );
 
 	qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
 	qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
+
+	menu_chars = GL_FindImage ("fonts/menu.tga", it_pic);
+
+	if(!menu_chars)
+		menu_chars = GL_LoadPic ("***font***", (byte *)data, 16, 16, it_pic, 32);
+
+	GL_Bind( menu_chars->texnum );
 	
 	con_font->modified = false;
 }
@@ -165,7 +212,7 @@ void Draw_ColorChar (int x, int y, int num, vec4_t color)
 	qglColor4f( 1,1,1,1 );
 }
 
-void Draw_ScaledChar (float x, float y, int num, float scale)
+void Draw_ScaledChar (float x, float y, int num, float scale, int from_menu)
 					
 {
 	int				row, col;
@@ -186,7 +233,11 @@ void Draw_ScaledChar (float x, float y, int num, float scale)
 	fcol = col*0.0625;
 	size = 0.0625;
 
-	GL_Bind(draw_chars->texnum);
+	if(from_menu)
+		GL_Bind(menu_chars->texnum);
+	else
+		GL_Bind(draw_chars->texnum);
+
 	qglColor4f( 1,1,1,1 );
 	qglBegin (GL_QUADS);
 	qglTexCoord2f (fcol, frow);
@@ -200,7 +251,7 @@ void Draw_ScaledChar (float x, float y, int num, float scale)
 	qglEnd();
 
 }
-void Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale)
+void Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale, int from_menu)
 {
 	int				row, col;
 	float			frow, fcol, size;
@@ -226,7 +277,10 @@ void Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale)
 	fcol = col*0.0625;
 	size = 0.0625;
 
-	GL_Bind (draw_chars->texnum);
+	if(from_menu)
+		GL_Bind(menu_chars->texnum);
+	else
+		GL_Bind(draw_chars->texnum);
 
 	qglColor4ubv( colors );
 	GL_TexEnv(GL_MODULATE);
@@ -359,6 +413,7 @@ void Draw_GetPicSize (int *w, int *h, char *pic)
 	*h = gl->height;
 	ShaderResizePic(gl, w, h);
 }
+
 #define DIV254BY255 (0.9960784313725490196078431372549f)
 void Draw_ShaderPic (image_t *gl, float alphaval)
 {
@@ -370,6 +425,12 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 	COM_StripExtension ( gl->name, shortname );
 	rs=RS_FindScript(shortname);
 
+	//if we draw the red team bar, we are on red team
+	if(!strcmp(shortname, "pics/i_team1"))
+		r_teamColor = 1;
+	else if(!strcmp(shortname, "pics/i_team2"))
+		r_teamColor = 2;
+
 	R_InitQuadVarrays(); 
 	
 	if (!rs) 
@@ -379,7 +440,19 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 		GLSTATE_DISABLE_ALPHATEST
 		GLSTATE_ENABLE_BLEND
 		GL_TexEnv( GL_MODULATE );
+
 		qglColor4f(1,1,1, alphaval);
+
+		//set color of hud by team
+		if(r_teamColor == 1) {
+			if(!strcmp(shortname, "pics/i_health")) 
+				qglColor4f(1, .2, .2, alphaval);
+		}
+		else if(r_teamColor == 2) {
+			if(!strcmp(shortname, "pics/i_health")) 
+				qglColor4f(.1, .4, .8, alphaval);
+		}
+			
 		VA_SetElem4(col_array[0], 1,1,1,1);
 		VA_SetElem4(col_array[1], 1,1,1,1);
 		VA_SetElem4(col_array[2], 1,1,1,1);
