@@ -18,6 +18,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+// for jpeglib
+#define HAVE_PROTOTYPES
+
 #include "r_local.h"
 #ifdef _WIN32
 #include "jpeg/jpeglib.h"
@@ -582,17 +585,17 @@ By Robert 'Heffo' Heffernan
 =================================================================
 */
 
-void jpg_null(j_decompress_ptr cinfo)
+void crjpg_null(j_decompress_ptr cinfo)
 {
 }
 
-unsigned char jpg_fill_input_buffer(j_decompress_ptr cinfo)
+int crjpg_fill_input_buffer(j_decompress_ptr cinfo)
 {
     Com_Printf("Premature end of JPEG data\n");
     return 1;
 }
 
-void jpg_skip_input_data(j_decompress_ptr cinfo, long num_bytes)
+void crjpg_skip_input_data(j_decompress_ptr cinfo, long num_bytes)
 {
         
     cinfo->src->next_input_byte += (size_t) num_bytes;
@@ -602,14 +605,14 @@ void jpg_skip_input_data(j_decompress_ptr cinfo, long num_bytes)
 		Com_Printf("Premature end of JPEG data\n");
 }
 
-void jpeg_mem_src(j_decompress_ptr cinfo, byte *mem, int len)
+void crjpg_mem_src(j_decompress_ptr cinfo, byte *mem, int len)
 {
     cinfo->src = (struct jpeg_source_mgr *)(*cinfo->mem->alloc_small)((j_common_ptr) cinfo, JPOOL_PERMANENT, sizeof(struct jpeg_source_mgr));
-    cinfo->src->init_source = jpg_null;
-    cinfo->src->fill_input_buffer = jpg_fill_input_buffer;
-    cinfo->src->skip_input_data = jpg_skip_input_data;
+    cinfo->src->init_source = crjpg_null;
+    cinfo->src->fill_input_buffer = crjpg_fill_input_buffer;
+    cinfo->src->skip_input_data = crjpg_skip_input_data;
     cinfo->src->resync_to_restart = jpeg_resync_to_restart;
-    cinfo->src->term_source = jpg_null;
+    cinfo->src->term_source = crjpg_null;
     cinfo->src->bytes_in_buffer = len;
     cinfo->src->next_input_byte = mem;
 }
@@ -650,7 +653,7 @@ void LoadJPG (char *filename, byte **pic, int *width, int *height)
 	jpeg_create_decompress(&cinfo);
 
 	// Feed JPEG memory into the libJpeg Object
-	jpeg_mem_src(&cinfo, rawdata, rawsize);
+	crjpg_mem_src(&cinfo, rawdata, rawsize);
 
 	// Process JPEG header
 	jpeg_read_header(&cinfo, true); // bombs out here
@@ -715,6 +718,9 @@ void LoadJPG (char *filename, byte **pic, int *width, int *height)
 	// Destroy JPEG object
 	jpeg_destroy_decompress(&cinfo);
 
+	// Free the raw data now that it's done being processed
+    FS_FreeFile(rawdata);
+
 	// Return the 'rgbadata'
 	*pic = rgbadata;
 }
@@ -1657,8 +1663,9 @@ void R_InitDepthTextures( void )
 	if(texture_height > 2048)
 		texture_height = 2048;
 	
-	//init the framebuffer texture
+	//init the framebuffer textures
 	size = texture_width * texture_height * 4;
+
 	data = malloc( size );
 	memset( data, 255, size );
 	r_depthtexture = GL_LoadPic( "***r_depthtexture***", (byte *)data, texture_width, texture_height, it_pic, 3 );
