@@ -316,124 +316,6 @@ void R_LightPoint (vec3_t p, vec3_t color, qboolean addDynamic)
 	VectorMA (color, gl_modulate->value, dlightcolor, color);
 }
 
-void R_LightPointDynamics (vec3_t p, vec3_t color, m_dlight_t *list, int *amount, int max)
-{
-	vec3_t		end;
-	float		r;
-	int			lnum, i, m_dl;
-	dlight_t	*dl;
-	vec3_t		dist, dlColor;
-	float		add;
-	worldLight_t *wl;
-
-	if (!r_worldmodel->lightdata)
-	{
-		color[0] = color[1] = color[2] = 1.0;
-		return;
-	}
-
-	end[0] = p[0];
-	end[1] = p[1];
-	end[2] = p[2] - 2048;
-
-	r = RecursiveLightPoint (r_worldmodel->nodes, p, end);
-
-	if (r == -1)
-	{
-		VectorCopy (vec3_origin, color);
-	}
-	else
-	{
-		VectorCopy (pointcolor, color);
-	}
-
-	//this catches too bright modulated color
-	for (i=0;i<3;i++)
-		if (color[i]>1) color[i] = 1;
-
-	m_dl = 0;
-
-	//add world lights
-	for (lnum=0; lnum<r_numWorldLights; lnum++) {
-
-		wl = &r_worldLights[lnum];
-
-		VectorSubtract (wl->origin, p, dist);
-
-		add = wl->intensity - VectorNormalize(dist)/3;
-		add *= (DIV256);
-		if (add > 0)
-		{
-			float highest = -1;
-
-
-			for (i=0;i<3;i++)
-				dlColor[i] = 1;
-
-			if (m_dl<max)
-			{
-				list[m_dl].strength = add;
-				VectorCopy(dist, list[m_dl].direction);
-				VectorScale(dlColor, add, dlColor);
-				VectorCopy(dlColor, list[m_dl].color);
-				m_dl++;
-			}
-		}
-	}
-
-	//
-	// add dynamic lights
-	//
-	dl = r_newrefdef.dlights;
-	for (lnum=0 ; lnum<r_newrefdef.num_dlights ; lnum++, dl++)
-	{
-
-		VectorSubtract (dl->origin, p, dist);
-
-		add = dl->intensity - VectorNormalize(dist);
-		add *= (DIV256);
-		if (add > 0)
-		{
-			float highest = -1;
-
-			VectorScale(dl->color, add, dlColor);
-			for (i=0;i<3;i++)
-				if (highest<dlColor[i]) highest = dlColor[i];
-
-			if (m_dl<max)
-			{
-				list[m_dl].strength = highest;
-				VectorCopy(dist, list[m_dl].direction);
-				VectorCopy(dlColor, list[m_dl].color);
-				m_dl++;
-			}
-			else
-			{
-				float	least_val = 10;
-				int		least_index = 0;
-
-				for (i=0;i<m_dl;i++)
-					if (list[i].strength<least_val)
-					{
-
-						least_val = list[i].strength;
-						least_index = i;
-					}
-
-				VectorAdd (color, list[least_index].color, color);
-				list[least_index].strength = highest;
-				VectorCopy(dist, list[least_index].direction);
-				VectorCopy(dlColor, list[least_index].color);
-			}
-		}
-	}
-
-	*amount = m_dl;
-
-
-}
-
-
 //===================================================================
 
 static float s_blocklights[34*34*3];
@@ -1055,133 +937,4 @@ void R_RenderSun()
 		qglPopMatrix();
 		qglMatrixMode(GL_MODELVIEW);
 	}
-}
-
-
-/*
-===============
-R_ShadowLight
-===============
-*/
-void vectoangles (vec3_t value1, vec3_t angles)
-{
-	float	forward;
-	float	yaw, pitch;
-
-	if (value1[1] == 0 && value1[0] == 0)
-	{
-		yaw = 0;
-		if (value1[2] > 0)
-			pitch = 90;
-		else
-			pitch = 270;
-	}
-	else
-	{
-	// PMM - fixed to correct for pitch of 0
-		if (value1[0])
-			yaw = (atan2(value1[1], value1[0]) * 180 / M_PI);
-		else if (value1[1] > 0)
-			yaw = 90;
-		else
-			yaw = 270;
-
-		if (yaw < 0)
-			yaw += 360;
-
-		forward = sqrt (value1[0]*value1[0] + value1[1]*value1[1]);
-		pitch = (atan2(value1[2], forward) * 180 / M_PI);
-		if (pitch < 0)
-			pitch += 360;
-	}
-
-	angles[PITCH] = -pitch;
-	angles[YAW] = yaw;
-	angles[ROLL] = 0;
-}
-
-float R_ShadowLight (vec3_t pos, vec3_t lightAdd, int type)
-{
-	int			lnum, i;
-	dlight_t	*dl;
-	worldLight_t *wl;
-	vec3_t		dist, angle;
-	float		add, /* len,*/ shadowdist;
-	float   	lintens, intens = 0;
-
-	if (!r_worldmodel)
-		return 0;
-	if (!r_worldmodel->lightdata) //keep old lame shadow
-		return 0;
-
-	VectorClear(lightAdd);
-	//
-	// add dynamic light shadow angles
-	//
-	if(!type) {
-		dl = r_newrefdef.dlights;
-		for (lnum=0; lnum<r_newrefdef.num_dlights; lnum++, dl++)
-		{
-
-			VectorSubtract (dl->origin, pos, dist);
-			add = sqrt(dl->intensity - VectorLength(dist));
-			VectorNormalize(dist);
-			if (add > 0)
-			{
-				VectorScale(dist, add, dist);
-				VectorAdd (lightAdd, dist, lightAdd);
-				intens = 0.3;
-			}
-		}
-	}
-	//
-	// add world light shadow angles
-	//
-	if(gl_shadows->integer == 2 && type) {
-
-		for (i=0; i<r_numWorldLights; i++) {
-
-			wl = &r_worldLights[i];			
-			
-			VectorSubtract (wl->origin, pos, dist);
-			add = sqrt(wl->intensity*10 - VectorLength(dist));
-			VectorNormalize(dist);
-			if (add > 0 && wl->origin[2] > pos[2]) 
-			{
-				VectorScale(dist, sqrt(add), dist);
-				VectorAdd (lightAdd, dist, lightAdd);
-				lintens = wl->intensity;
-				if(lintens < 300)
-					lintens = 300;
-				intens+=(lintens/1000 - VectorLength(dist)/30); //darken shadows where light is stronger
-			}
-		}
-
-		//cap some limits of lightness, darkness, subtley.
-		if (intens < 0.3)
-			intens = 0.3;
-		if (intens > 0.5)
-			intens = 0.5;
-	}
-
-	// Barnes improved code
-	shadowdist = VectorNormalize(lightAdd);
-	if (shadowdist > 4) shadowdist = 4;
-	if (shadowdist <= 0) // old style static shadow
-	{
-		angle[PITCH] = currententity->angles[PITCH];
-		angle[YAW] =   -currententity->angles[YAW];
-		angle[ROLL] =   currententity->angles[ROLL];
-		shadowdist = 1;
-	}
-	else // shadow from dynamic lights
-	{
-		vectoangles (lightAdd, angle);
-		angle[YAW] -= currententity->angles[YAW];
-	}
-	AngleVectors (angle, dist, NULL, NULL);
-	VectorScale (dist, shadowdist, lightAdd);
-	// end Barnes improved code
-
-	return intens;
-}
+}
\ No newline at end of file
