@@ -165,7 +165,6 @@ extern	cvar_t	*gl_texturemode;
 extern	cvar_t	*gl_texturealphamode;
 extern	cvar_t	*gl_texturesolidmode;
 extern	cvar_t	*gl_lockpvs;
-extern	cvar_t	*gl_rtlights;
 
 extern	cvar_t	*vid_fullscreen;
 extern	cvar_t	*vid_gamma;
@@ -176,16 +175,12 @@ extern	cvar_t	*intensity;
 extern cvar_t *r_anisotropic;
 extern cvar_t *r_ext_max_anisotropy;
 
-// Vic - begin
-
 extern cvar_t	*r_overbrightbits;
 extern cvar_t	*gl_ext_mtexcombine;
 
-// Vic - end
 extern cvar_t	*gl_normalmaps;
 extern cvar_t	*gl_shadowmaps;
 extern cvar_t	*gl_parallaxmaps;
-extern cvar_t	*gl_specular;
 extern cvar_t	*gl_glsl_postprocess;
 
 extern	cvar_t	*r_shaders;
@@ -237,7 +232,6 @@ void GL_EnableMultitexture( qboolean enable );
 void GL_SelectTexture( GLenum );
 void vectoangles (vec3_t value1, vec3_t angles);
 void R_LightPoint (vec3_t p, vec3_t color, qboolean addDynamic);
-void R_LightPointDynamics (vec3_t p, vec3_t color, m_dlight_t *list, int *amount, int max);
 void R_PushDlights (void);
 void R_PushDlightsForBModel (entity_t *e);
 void SetVertexOverbrights (qboolean toggle);
@@ -295,8 +289,6 @@ void R_ClearSkyBox (void);
 void R_DrawSkyBox (void);
 void R_MarkLights (dlight_t *light, int bit, mnode_t *node);
 float R_ShadowLight (vec3_t pos, vec3_t lightAdd, int type);
-void R_DrawShadowVolume(entity_t * e);
-void R_ShadowBlend(float alpha);
 #ifdef __unix__
 void R_ReadFogScript(char config_file[128]);
 void R_ReadMusicScript(char config_file[128]);
@@ -331,14 +323,17 @@ qboolean spacebox;
 //Player icons
 extern float	scr_playericonalpha;
 
+//Team colors
+int r_teamColor;
+
 void	Draw_GetPicSize (int *w, int *h, char *name);
 void	Draw_Pic (int x, int y, char *name);
 void	Draw_ScaledPic (int x, int y, float scale, char *pic);
 void	Draw_StretchPic (int x, int y, int w, int h, char *name);
 void	Draw_Char (int x, int y, int c);
 void	Draw_ColorChar (int x, int y, int num, vec4_t color);
-void	Draw_ScaledChar(float x, float y, int num, float scale);
-void	Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale);
+void	Draw_ScaledChar(float x, float y, int num, float scale, int from_menu);
+void	Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale, int from_menu);
 void	Draw_TileClear (int x, int y, int w, int h, char *name);
 void	Draw_Fill (int x, int y, int w, int h, int c);
 void	Draw_FadeScreen (void);
@@ -520,23 +515,28 @@ extern vec3_t ShadowArray[MAX_SHADOW_VERTS];
 void R_InitVArrays (int varraytype);
 void R_KillVArrays (void);
 void R_InitQuadVarrays(void);
+void R_AddSurfToVArray (msurface_t *surf);
 void R_AddTexturedSurfToVArray (msurface_t *surf, float scroll);
 void R_AddLightMappedSurfToVArray (msurface_t *surf, float scroll);
-void R_AddGLSLShadedSurfToVArray (msurface_t *surf, float scroll, qboolean lightmap);
+void R_AddGLSLShadedSurfToVArray (msurface_t *surf, float scroll);
 void R_AddGLSLShadedWarpSurfToVArray (msurface_t *surf, float scroll);
 void R_KillNormalTMUs(void);
 
-// stencil volumes
-extern glStencilFuncSeparatePROC	qglStencilFuncSeparate;
-extern glStencilOpSeparatePROC		qglStencilOpSeparate;
-extern glStencilMaskSeparatePROC	qglStencilMaskSeparate;
-
-//shadow maps
-GLuint fboId;
-void setupMatrices(float position_x,float position_y,float position_z,float lookAt_x,float lookAt_y,float lookAt_z);
-void setTextureMatrix();
-void R_DrawShadowMapWorld (void);
-extern image_t *r_depthtexture;
+//shadows
+extern	cvar_t		*r_shadowmapratio;
+extern  int			r_lightgroups;
+extern  image_t		*r_depthtexture;
+extern GLuint   fboId;
+typedef struct	LightGroup {
+	vec3_t	group_origin;
+	vec3_t	accum_origin;
+	float	avg_intensity;
+	float	dist;
+} LightGroup_t;
+extern			LightGroup_t LightGroups[MAX_LIGHTS];
+extern void		R_DrawAliasModelCaster (entity_t *e);
+extern void		R_DrawDynamicCaster(void);
+extern void		R_CastShadow(void);
 
 //arb fragment
 extern unsigned int g_water_program_id;
@@ -558,13 +558,13 @@ extern GLuint		g_location_heightTexture;
 extern GLuint		g_location_lmTexture;
 extern GLuint		g_location_normalTexture;
 extern GLuint		g_location_bspShadowmapTexture;
-extern GLuint		g_heightMapID;
+extern GLuint		g_location_bspShadowmapNum;
 extern GLuint		g_location_fog;
 extern GLuint		g_location_parallax;
 extern GLuint		g_location_dynamic;
-extern GLuint		g_location_specular;
 extern GLuint		g_location_shadowmap;
 extern GLuint		g_location_lightPosition;
+extern GLuint		g_location_staticLightPosition;
 extern GLuint		g_location_lightColour;
 extern GLuint		g_location_lightCutoffSquared;
 
