@@ -20,7 +20,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // r_mesh.c: triangle model functions
 
 #include "r_local.h"
-#include "vlights.h"
 
 /*
 =============================================================
@@ -43,7 +42,6 @@ static	vec3_t	s_normals[MAX_VERTS];
 extern	vec3_t	lightspot;
 vec3_t	shadevector;
 float	shadelight[3];
-vec3_t	lightdir;
 
 #define MAX_MODEL_DLIGHTS 128
 m_dlight_t model_dlights[MAX_MODEL_DLIGHTS];
@@ -72,9 +70,6 @@ GL_VlightAliasModel
 
 Vertex lighting for Alias models
 
-When rtlights is set we get a smoother, more accurate model shading.  If normalmaps are on
-we scale the light a bit less, as normalmaps tend to add a bit of contrast.
-
 Contrast has been added by finding a threshold point, and scaling values on either side in 
 opposite directions.  This gives the shading a more prounounced, defined look.
 
@@ -88,30 +83,9 @@ void GL_VlightAliasModel (vec3_t baselight, dtrivertx_t *verts, dtrivertx_t *ov,
 
     lscale = 3.0;
 
-	VectorSubtract(currententity->origin, lightspot, lightdir);
-	VectorNormalize ( lightdir );
-
-    if (gl_rtlights->value)
-    {
-        l = lscale * VLight_LerpLight (verts->lightnormalindex, ov->lightnormalindex,
-                                backlerp, lightdir, currententity->angles, false);
-
-        VectorScale(baselight, l, lightOut);
-
-        if (model_dlights_num)
-            for (i=0; i<model_dlights_num; i++)
-            {
-                l = lscale * VLight_LerpLight (verts->lightnormalindex, ov->lightnormalindex,
-                    backlerp, model_dlights[i].direction, currententity->angles, true );
-                VectorMA(lightOut, l, model_dlights[i].color, lightOut);
-            }
-    }
-    else
-    {
-        l = shadedots[verts->lightnormalindex];
-        VectorScale(baselight, l, lightOut);
-    }
-
+    l = shadedots[verts->lightnormalindex];
+    VectorScale(baselight, l, lightOut);
+    
     for (i=0; i<3; i++)
     {        
 		//add contrast - lights lighter, darks darker
@@ -134,13 +108,6 @@ void GL_LerpSelfShadowVerts( int nverts, dtrivertx_t *v, dtrivertx_t *ov, float
         }
 }
 
-/*
-=============
-GL_DrawAliasFrameLerp
-
-interpolates between two frames and origins
-=============
-*/
 float calcEntAlpha (float alpha, vec3_t point)
 {
 	float newAlpha;
@@ -174,12 +141,12 @@ void GL_GetLightVals()
 {
 	int i, j, lnum;
 	dlight_t	*dl;
-	worldLight_t *wl;
 	float dist, xdist, ydist;
-	vec3_t	temp, lightAdd;
+	vec3_t	temp, tempOrg, lightAdd;
 	trace_t r_trace;
 	vec3_t mins, maxs;
 	float numlights, weight;
+	float bob;
 	
 	VectorSet(mins, 0, 0, 0);
 	VectorSet(maxs, 0, 0, 0);
@@ -188,29 +155,32 @@ void GL_GetLightVals()
 	VectorCopy(currententity->origin, lightPosition);
 	lightPosition[2] += 128; 
 
+	if(currententity->flags & RF_BOBBING) 
+		bob = currententity->bob;
+	else
+		bob = 0;
+
+	VectorCopy(currententity->origin, tempOrg);
+		tempOrg[2] += 24 - bob; //generates more consistent tracing
+
 	numlights = 0;
 	VectorClear(lightAdd);
-	for (i=0; i<r_numWorldLights; i++) {
+	for (i=0; i<r_lightgroups; i++) {	
 
-		wl = &r_worldLights[i];
-
-		VectorCopy(currententity->origin, temp);
-		temp[2] += 24; //generates more consistent tracing
-
-		if((currententity->flags & RF_WEAPONMODEL) && (wl->origin[2] > currententity->origin[2]))
+		if((currententity->flags & RF_WEAPONMODEL) && (LightGroups[i].group_origin[2] > currententity->origin[2]))
 			r_trace.fraction = 1.0; //don't do traces for weapon models, not smooth enough
 		else
-			r_trace = CM_BoxTrace(temp, wl->origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
+			r_trace = CM_BoxTrace(tempOrg, LightGroups[i].group_origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
 		
 		if(r_trace.fraction == 1.0) {
-			VectorSubtract(currententity->origin, wl->origin, temp);
+			VectorSubtract(currententity->origin, LightGroups[i].group_origin, temp);
 			dist = VectorLength(temp);
-			if(dist == 0)
+			if(dist == 0) 
 				dist = 1;
 			dist = dist*dist;
-			weight = (int)250000/dist;
+			weight = (int)250000/(dist/(LightGroups[i].avg_intensity+1.0f));
 			for(j = 0; j < 3; j++) 
-				lightAdd[j] += wl->origin[j]*weight;
+				lightAdd[j] += LightGroups[i].group_origin[j]*weight;
 			numlights+=weight;				
 		}
 	}
@@ -243,8 +213,8 @@ void GL_GetLightVals()
 					}
 					//make dynamic lights more influential than world
 					for(j = 0; j < 3; j++)
-						lightAdd[j] += temp[j]*100;
-					numlights+=100;
+						lightAdd[j] += temp[j]*100*dl->intensity;
+					numlights+=100*dl->intensity;
                 
 					VectorSubtract (dl->origin, currententity->origin, temp);
 					dynFactor += (dl->intensity/20.0)/VectorLength(temp);
@@ -954,7 +924,7 @@ void GL_DrawAliasFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int
 		}
 
 		if(currententity->flags & RF_VIEWERMODEL) { //lerp the vertices for self shadows, and leave
-			if(gl_shadows->value && gl_shadows->value < 3) {
+			if(gl_shadows->value && !gl_shadowmaps->value) {
 				lerp = s_lerped[0];
 				GL_LerpSelfShadowVerts( paliashdr->num_xyz, v, ov, lerp, move, frontv, backv);
 				return;
@@ -1801,66 +1771,55 @@ void R_DrawAliasModel (entity_t *e)
 		for (i=0 ; i<3 ; i++)
 			shadelight[i] = 1.0;
 	}
-	else if(gl_rtlights->value && !gl_normalmaps->value) //no need when normalmaps are used, which should be for all meshes.
-	{
-		int max = 3;
-
-		if (max<0)max=0;
-		if (max>MAX_MODEL_DLIGHTS)max=MAX_MODEL_DLIGHTS;
-
-		R_LightPointDynamics (currententity->origin, shadelight, model_dlights,
-			&model_dlights_num, max);
-	}
 	else
 	{
 		R_LightPoint (currententity->origin, shadelight, true);
 	}
 	if ( currententity->flags & RF_MINLIGHT )
 	{
+		float minlight;
+
+		if(gl_glsl_shaders->value && gl_state.glsl_shaders && gl_normalmaps->value) 
+			minlight = 0.1;
+		else
+			minlight = 0.2;
 		for (i=0 ; i<3 ; i++)
-			if (shadelight[i] > 0.1)
+			if (shadelight[i] > minlight)
 				break;
 		if (i == 3)
 		{
-			shadelight[0] = 0.1;
-			shadelight[1] = 0.1;
-			shadelight[2] = 0.1;
+			shadelight[0] = minlight;
+			shadelight[1] = minlight;
+			shadelight[2] = minlight;
 		}
 	}
 
 	if ( currententity->flags & RF_GLOW )
 	{	// bonus items will pulse with time
 		float	scale;
-		float	min;
+		float	minlight;
 
 		scale = 0.2 * sin(r_newrefdef.time*7);
+		if(gl_glsl_shaders->value && gl_state.glsl_shaders && gl_normalmaps->value) 
+			minlight = 0.1;
+		else
+			minlight = 0.2;
 		for (i=0 ; i<3 ; i++)
-		{
-			min = shadelight[i] * 0.8;
+		{			
 			shadelight[i] += scale;
-			if (shadelight[i] < min)
-				shadelight[i] = min;
+			if (shadelight[i] < minlight)
+				shadelight[i] = minlight;
 		}
 	}
 
-// =================
-// PGM	ir goggles color override
-	if ( r_newrefdef.rdflags & RDF_IRGOGGLES && currententity->flags & RF_IR_VISIBLE)
-	{
-		shadelight[0] = 1.0;
-		shadelight[1] = 0.0;
-		shadelight[2] = 0.0;
-	}
-// PGM
-// =================
-
 	shadedots = r_avertexnormal_dots[((int)(currententity->angles[1] * (SHADEDOT_QUANT / 360.0))) & (SHADEDOT_QUANT - 1)];
 
 	//
 	// locate the proper data
 	//
 
-	c_alias_polys += paliashdr->num_tris;
+	if ( !(currententity->flags & RF_VIEWERMODEL) )
+		c_alias_polys += paliashdr->num_tris; // for r_speeds epoly count
 
 	//
 	// draw all the triangles
@@ -1993,7 +1952,7 @@ void R_DrawAliasModel (entity_t *e)
 		qglDepthRange (gldepthmin, gldepthmax);
 
 	//old legacy shadows
-	if (!(r_newrefdef.rdflags & RDF_NOWORLDMODEL) && gl_shadows->value && gl_shadows->value < 3 && !(currententity->flags & (RF_WEAPONMODEL | RF_NOSHADOWS)))
+	if (!(r_newrefdef.rdflags & RDF_NOWORLDMODEL) && gl_shadows->value && !gl_shadowmaps->value && !(currententity->flags & (RF_WEAPONMODEL | RF_NOSHADOWS)))
 	{
 		float casted;
 		float an = currententity->angles[1]/180*M_PI;
@@ -2015,9 +1974,9 @@ void R_DrawAliasModel (entity_t *e)
 			qglEnable (GL_BLEND);
 
 			if (currententity->flags & RF_TRANSLUCENT)
-				qglColor4f (0,0,0,0.4 * currententity->alpha); //Knightmare- variable alpha
+				qglColor4f (0,0,0,0.3 * currententity->alpha); //Knightmare- variable alpha
 			else
-				qglColor4f (0,0,0,0.4);
+				qglColor4f (0,0,0,0.3);
 			
 			if(e->frame == 0 && currentmodel->num_frames == 1)
 				R_DrawAliasShadow (paliashdr, false);
@@ -2099,4 +2058,156 @@ void R_DrawAliasModel (entity_t *e)
 
 }
 
+void GL_DrawAliasCasterFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped)
+{
+	daliasframe_t	*frame, *oldframe;
+	dtrivertx_t	*v, *ov, *verts;
+	dtriangle_t		*tris;
+	float	frontlerp;
+	vec3_t	move, delta, vectors[3];
+	vec3_t	frontv, backv;
+	int		i, j;
+	int		index_xyz, index_st;
+	int		va = 0;
+	fstvert_t *st;
 
+	if(lerped)
+		frame = (daliasframe_t *)((byte *)paliashdr + paliashdr->ofs_frames
+			+ currententity->frame * paliashdr->framesize);
+	else
+		frame = (daliasframe_t *)((byte *)paliashdr + paliashdr->ofs_frames);
+	verts = v = frame->verts;
+
+	if(lerped) {
+		oldframe = (daliasframe_t *)((byte *)paliashdr + paliashdr->ofs_frames
+			+ currententity->oldframe * paliashdr->framesize);
+		ov = oldframe->verts;
+	}
+
+	tris = (dtriangle_t *) ((byte *)paliashdr + paliashdr->ofs_tris);
+
+	st = currentmodel->st;
+
+	if(lerped) {
+		frontlerp = 1.0 - backlerp;
+
+		// move should be the delta back to the previous frame * backlerp
+		VectorSubtract (currententity->oldorigin, currententity->origin, delta);
+	}
+
+	AngleVectors (currententity->angles, vectors[0], vectors[1], vectors[2]);
+
+	if(lerped) {
+		move[0] = DotProduct (delta, vectors[0]);	// forward
+		move[1] = -DotProduct (delta, vectors[1]);	// left
+		move[2] = DotProduct (delta, vectors[2]);	// up
+
+		VectorAdd (move, oldframe->translate, move);
+
+		for (i=0 ; i<3 ; i++)
+		{
+			move[i] = backlerp*move[i] + frontlerp*frame->translate[i];
+			frontv[i] = frontlerp*frame->scale[i];
+			backv[i] = backlerp*oldframe->scale[i];
+		}
+	
+	}
+
+	va=0;
+	VArray = &VArrayVerts[0];
+	R_InitVArrays (VERT_NO_TEXTURE);
+
+	for (i=0; i<paliashdr->num_tris; i++)
+	{
+		for (j=0; j<3; j++)
+		{			
+			index_xyz = tris[i].index_xyz[j];
+			index_st = tris[i].index_st[j];
+												
+			if(lerped) {
+				
+				VArray[0] = s_lerped[index_xyz][0] = move[0] + ov[index_xyz].v[0]*backv[0] + v[index_xyz].v[0]*frontv[0];
+				VArray[1] = s_lerped[index_xyz][1] = move[1] + ov[index_xyz].v[1]*backv[1] + v[index_xyz].v[1]*frontv[1];
+				VArray[2] = s_lerped[index_xyz][2] = move[2] + ov[index_xyz].v[2]*backv[2] + v[index_xyz].v[2]*frontv[2];
+	
+			}
+			else {				
+
+				VArray[0] = currentmodel->r_mesh_verts[index_xyz][0];
+				VArray[1] = currentmodel->r_mesh_verts[index_xyz][1];
+				VArray[2] = currentmodel->r_mesh_verts[index_xyz][2];
+
+			}
+		
+			// increment pointer and counter
+			VArray += VertexSizes[VERT_NO_TEXTURE];
+			va++;			
+		} 	
+
+	}
+	
+	if(qglLockArraysEXT)						
+		qglLockArraysEXT(0, va);
+
+	qglDrawArrays(GL_TRIANGLES,0,va);
+			
+	if(qglUnlockArraysEXT)						
+		qglUnlockArraysEXT();
+
+	R_KillVArrays ();
+}
+
+//to do - alpha and alphamasks possible?
+void R_DrawAliasModelCaster (entity_t *e)
+{
+	vec3_t		bbox[8];
+	dmdl_t		*paliashdr;
+
+	if(e->team) //don't draw flag models, handled by sprites
+		return;
+	
+	if ( e->flags & RF_WEAPONMODEL ) //don't draw weapon model shadow casters
+		return;
+
+	if ( currententity->flags & ( RF_SHELL_HALF_DAM | RF_SHELL_GREEN | RF_SHELL_RED | RF_SHELL_BLUE | RF_SHELL_DOUBLE) ) //no shells
+		return;
+
+	if ( R_CullAliasModel( bbox, e ) )
+		return;
+
+	paliashdr = (dmdl_t *)currentmodel->extradata;
+
+	// draw it
+
+    qglPushMatrix ();
+	e->angles[PITCH] = -e->angles[PITCH];
+	R_RotateForEntity (e);
+	e->angles[PITCH] = -e->angles[PITCH];
+
+	if ( (currententity->frame >= paliashdr->num_frames)
+		|| (currententity->frame < 0) )
+	{
+		currententity->frame = 0;
+		currententity->oldframe = 0;
+	}
+
+	if ( (currententity->oldframe >= paliashdr->num_frames)
+		|| (currententity->oldframe < 0))
+	{
+		currententity->frame = 0;
+		currententity->oldframe = 0;
+	}
+
+	if ( !r_lerpmodels->value )
+		currententity->backlerp = 0;
+
+	if(e->frame == 0 && currentmodel->num_frames == 1)
+		GL_DrawAliasCasterFrame(paliashdr, 0, false);
+	else
+		GL_DrawAliasCasterFrame(paliashdr, currententity->backlerp, true);
+
+	qglPopMatrix();
+	qglMatrixMode(GL_MODELVIEW);
+	qglPopMatrix();
+
+}
