@@ -30,58 +30,62 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <jpeglib.h>
 #endif
 
-image_t *r_flare;
-image_t *r_cubemap;
+image_t		*r_notexture;		// use for bad textures
+image_t		*r_particletexture;	// little dot for particles
+image_t		*r_smoketexture;	// for smoke, etc...
+image_t		*r_explosiontexture;
+image_t		*r_explosion1texture;
+image_t		*r_explosion2texture;
+image_t		*r_explosion3texture;
+image_t		*r_explosion4texture;
+image_t		*r_explosion5texture;
+image_t		*r_explosion6texture;
+image_t		*r_explosion7texture;
+image_t		*r_bloodtexture;
+image_t		*r_pufftexture;
+image_t		*r_bflashtexture;
+image_t		*r_cflashtexture;
+image_t		*r_leaderfieldtexture;
+image_t		*r_deathfieldtexture;
+image_t		*r_deathfieldtexture2;
+image_t		*r_shelltexture; 
+image_t		*r_shelltexture2;
+image_t		*r_shellnormal;  
+image_t		*r_hittexture;
+image_t		*r_bubbletexture;
+image_t		*r_reflecttexture;
+image_t		*r_shottexture;
+image_t		*r_sayicontexture;
+image_t		*r_flaretexture;
+image_t		*r_flagtexture;
+image_t		*r_logotexture;
+image_t		*r_beamtexture;
+image_t		*r_beam2texture;
+image_t		*r_beam3texture;
+image_t		*r_dis1texture;
+image_t		*r_dis2texture;
+image_t		*r_dis3texture;
+image_t		*r_bullettexture;
+image_t		*r_bulletnormal;
+image_t		*r_voltagetexture;
+image_t		*r_raintexture;
+image_t		*r_leaftexture;
+image_t		*r_splashtexture;
+image_t		*r_splash2texture;
+image_t		*r_radarmap; 
+image_t		*r_around;
+image_t		*r_flare;
+image_t		*r_flare1;
+image_t		*r_mirrorspec; 
+image_t		*r_distort;
+image_t		*sun_object;
+image_t		*sun1_object;
+image_t		*sun2_object;
+
+//Normalisation cube map
+GLuint normalisationCubeMap;
 
 #define CUBEMAP_MAXSIZE 32
-void MakeSpecularAttenuationMap (byte *pixels)
-{
-	int x, y;
-	int LRADIUS = CUBEMAP_MAXSIZE / 2;
-
-	for (y = 0; y < CUBEMAP_MAXSIZE; y++)
-	{
-		for (x = 0; x < CUBEMAP_MAXSIZE; x++)
-		{
-			// find x and y as a -LRADIUS to LRADIUS scale
-			int TheRX = x - LRADIUS;
-			int TheRY = y - LRADIUS;
-			float TheXResult;
-			float TheYResult;
-			float TheFinalResult;
-			unsigned char OutResult;
-
-			// divide X by LRADIUS and square it
-			TheXResult = ((float) TheRX / (float) LRADIUS);
-			TheXResult *= TheXResult;
-
-			// divide Y by LRADIUS and square it
-			TheYResult = ((float) TheRY / (float) LRADIUS);
-			TheYResult *= TheYResult;
-
-			// add the 2
-			TheFinalResult = TheXResult + TheYResult;
-
-			// multiply by 255 for a byte intensity range
-			TheFinalResult = TheFinalResult * 255;
-
-			// clamp 0 to 255
-			if (TheFinalResult < 0) TheFinalResult = 0;
-			if (TheFinalResult > 255) TheFinalResult = 255;
-
-			// store in an unsigned char now - we want the negative of what is generated above
-			OutResult = 255 - (unsigned char) TheFinalResult;
-
-			// write to output
-			pixels[0] = OutResult;
-			pixels[1] = OutResult;
-			pixels[2] = OutResult;
-			pixels[3] = 255;
-
-			pixels += 4;
-		}
-	}
-}
 
 static void getCubeVector (int i, int cubesize, int x, int y, float *vector)
 {
@@ -116,13 +120,10 @@ void R_InitCubemapTextures (void)
 	int i, x, y;
 	byte pixels[CUBEMAP_MAXSIZE * CUBEMAP_MAXSIZE * 4];
 
-	// switch the texture state
 	qglDisable (GL_TEXTURE_2D);
 	qglEnable (GL_TEXTURE_CUBE_MAP_ARB);
 
-	// bind to the regular texture number
-	qglBindTexture (GL_TEXTURE_CUBE_MAP_ARB, r_cubemap->texnum);
-	qglGetError(); //binding this 2d texture initially causes a harmless error
+	qglBindTexture(GL_TEXTURE_CUBE_MAP_ARB, normalisationCubeMap);
 
 	// set up the texture parameters - did a clamp on R as well...
 	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
@@ -130,7 +131,7 @@ void R_InitCubemapTextures (void)
 	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_WRAP_R, GL_CLAMP_TO_EDGE);
 	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-
+	
 	for (i = 0; i < 6; i++)
 	{
 		for (y = 0; y < CUBEMAP_MAXSIZE; y++)
@@ -148,8 +149,6 @@ void R_InitCubemapTextures (void)
 		// cube map me baybeee
 		qglTexImage2D (GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB + i, 0, GL_RGBA, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
 	}
-	MakeSpecularAttenuationMap (pixels);
-	qglTexImage2D (GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB, 0, GL_RGBA, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
 
 	// done - restore the texture state
 	qglDisable (GL_TEXTURE_CUBE_MAP_ARB);
@@ -185,8 +184,8 @@ void R_InitParticleTexture (void)
 {
 	int		x,y;
 	byte	data[16][16][4];
-	byte pixels[CUBEMAP_MAXSIZE * CUBEMAP_MAXSIZE * 4];
 	char flares[MAX_QPATH];
+
 	//
 	// particle texture
 	//
@@ -197,49 +196,203 @@ void R_InitParticleTexture (void)
 			data[y][x][0] = 255;
 			data[y][x][1] = 255;
 			data[y][x][2] = 255;
-			data[y][x][3] = dottexture[x][y]; // c14 Just this line changes
+			data[y][x][3] = dottexture[x][y]; 
 		}
 	}
-	r_particletexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
 
-	r_smoketexture = R_RegisterParticlePic("smoke");//etc etc etc...
-    r_particletexture = R_RegisterParticlePic("particle");
-	r_explosiontexture = R_RegisterParticlePic("explosion");
-	r_explosion1texture = R_RegisterParticlePic("r_explod_1");
-	r_explosion2texture = R_RegisterParticlePic("r_explod_2");
-	r_explosion3texture = R_RegisterParticlePic("r_explod_3");
-	r_explosion4texture = R_RegisterParticlePic("r_explod_4");
-	r_explosion5texture = R_RegisterParticlePic("r_explod_5");
-	r_explosion6texture = R_RegisterParticlePic("r_explod_6");
-	r_explosion7texture = R_RegisterParticlePic("r_explod_7");
-	r_bloodtexture = R_RegisterParticlePic("blood");
-	r_pufftexture = R_RegisterParticlePic("puff");
-	r_blastertexture = R_RegisterParticlePic("blaster");
-	r_bflashtexture = R_RegisterParticlePic("bflash");
-	r_cflashtexture = R_RegisterParticlePic("cflash");
-	r_leaderfieldtexture = R_RegisterParticlePic("leaderfield");
-	r_deathfieldtexture = R_RegisterParticlePic("deathfield");
-	r_shelltexture = R_RegisterParticlePic("shell");
-	r_hittexture = R_RegisterParticlePic("aflash");
-	r_bubbletexture = R_RegisterParticlePic("bubble");
-	r_reflecttexture = R_RegisterParticlePic("reflect");
-	r_shottexture = R_RegisterParticlePic("dflash");
-	r_sayicontexture = R_RegisterParticlePic("sayicon");
-	r_flaretexture = R_RegisterParticlePic("flare");
-	r_beamtexture = R_RegisterGfxPic("glightning");
-	r_beam2texture = R_RegisterGfxPic("greenline");
-	r_beam3texture = R_RegisterGfxPic("electrics3d");
-	r_bullettexture = R_RegisterParticlePic("bullethole");
-	r_voltagetexture = R_RegisterParticlePic("voltage");
-	r_raintexture = R_RegisterParticlePic("beam");
-	r_radarmap = GL_FindImage("gfx/radar/radarmap",it_pic);
-	r_around = GL_FindImage("gfx/radar/around",it_pic);
-
-	//do this for all so as to not have crashes
-	if (!r_particletexture) {                                 //c14 add this line
+	r_particletexture = R_RegisterParticlePic("particle");
+	if (!r_particletexture) {                                
 		r_particletexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
-    }                                                         //c14 add this line
-
+    }
+	r_smoketexture = R_RegisterParticlePic("smoke");
+	if (!r_smoketexture) {                                
+		r_smoketexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosiontexture = R_RegisterParticlePic("explosion");
+	if (!r_explosiontexture) {                                
+		r_explosiontexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion1texture = R_RegisterParticlePic("r_explod_1");
+	if (!r_explosion1texture) {                                
+		r_explosion1texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion2texture = R_RegisterParticlePic("r_explod_2");
+	if (!r_explosion2texture) {                                
+		r_explosion2texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion3texture = R_RegisterParticlePic("r_explod_3");
+	if (!r_explosion3texture) {                                
+		r_explosion3texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion4texture = R_RegisterParticlePic("r_explod_4");
+	if (!r_explosion4texture) {                                
+		r_explosion4texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion5texture = R_RegisterParticlePic("r_explod_5");
+	if (!r_explosion5texture) {                                
+		r_explosion5texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion6texture = R_RegisterParticlePic("r_explod_6");
+	if (!r_explosion6texture) {                                
+		r_explosion6texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_explosion7texture = R_RegisterParticlePic("r_explod_7");
+	if (!r_explosion7texture) {                                
+		r_explosion7texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_bloodtexture = R_RegisterParticlePic("blood");
+	if (!r_bloodtexture) {                                
+		r_bloodtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_pufftexture = R_RegisterParticlePic("puff");
+	if (!r_pufftexture) {                                
+		r_pufftexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_bflashtexture = R_RegisterParticlePic("bflash");
+	if (!r_bflashtexture) {                                
+		r_bflashtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_cflashtexture = R_RegisterParticlePic("cflash");
+	if (!r_cflashtexture) {                                
+		r_cflashtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_leaderfieldtexture = R_RegisterParticlePic("leaderfield");
+	if (!r_leaderfieldtexture) {                                
+		r_leaderfieldtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_deathfieldtexture = R_RegisterParticlePic("deathfield");
+	if (!r_deathfieldtexture) {                                
+		r_deathfieldtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_deathfieldtexture2 = R_RegisterParticlePic("deathfield2");
+	if (!r_deathfieldtexture2) {                                
+		r_deathfieldtexture2 = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_shelltexture = R_RegisterParticlePic("shell");
+	if (!r_shelltexture) {                                
+		r_shelltexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }  
+	r_shelltexture2 = R_RegisterParticlePic("shell2");
+	if (!r_shelltexture2) {                                
+		r_shelltexture2 = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    } 
+	r_shellnormal = R_RegisterParticlePic("shell2_normal");
+	if (!r_shellnormal) {                                
+		r_shellnormal = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    } 
+	r_hittexture = R_RegisterParticlePic("aflash");
+	if (!r_hittexture) {                                
+		r_hittexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_bubbletexture = R_RegisterParticlePic("bubble");
+	if (!r_bubbletexture) {                                
+		r_bubbletexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_reflecttexture = R_RegisterParticlePic("reflect");
+	if (!r_reflecttexture) {                                
+		r_reflecttexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_mirrorspec = R_RegisterGfxPic("mirrorspec");
+	if (!r_mirrorspec) {                                
+		r_mirrorspec = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_shottexture = R_RegisterParticlePic("dflash");
+	if (!r_shottexture) {                                
+		r_shottexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_sayicontexture = R_RegisterParticlePic("sayicon");
+	if (!r_sayicontexture) {                                
+		r_sayicontexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_flaretexture = R_RegisterParticlePic("flare");
+	if (!r_flaretexture) {                                
+		r_flaretexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_flagtexture = R_RegisterParticlePic("flag");
+	if (!r_flagtexture) {                                
+		r_flagtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_logotexture = R_RegisterParticlePic("logo");
+	if (!r_logotexture) {                                
+		r_logotexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_beamtexture = R_RegisterGfxPic("glightning");
+	if (!r_beamtexture) {                                
+		r_beamtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_beam2texture = R_RegisterGfxPic("greenline");
+	if (!r_beam2texture) {                                
+		r_beam2texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_beam3texture = R_RegisterGfxPic("electrics3d");
+	if (!r_beam3texture) {                                
+		r_beam3texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_bullettexture = R_RegisterParticlePic("bullethole");
+	if (!r_bullettexture) {                                
+		r_bullettexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_bulletnormal = R_RegisterParticleNormal("bullethole2");
+	if (!r_bulletnormal) {                                
+		r_bulletnormal = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_voltagetexture = R_RegisterParticlePic("voltage");
+	if (!r_voltagetexture) {                                
+		r_voltagetexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_raintexture = R_RegisterParticlePic("beam");
+	if (!r_raintexture) {                                
+		r_raintexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }
+	r_leaftexture = R_RegisterParticlePic("leaf");
+	if (!r_leaftexture) {                                
+		r_leaftexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }   
+	r_splashtexture = R_RegisterParticlePic("ripples");
+	if (!r_splashtexture) {                                
+		r_splashtexture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }   
+	r_splash2texture = R_RegisterParticlePic("watersplash");
+	if (!r_splash2texture) {                                
+		r_splash2texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }  
+	r_radarmap = GL_FindImage("gfx/radar/radarmap",it_pic);
+	if (!r_radarmap) {                                
+		r_radarmap = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
+	r_around = GL_FindImage("gfx/radar/around",it_pic);
+	if (!r_around) {                                
+		r_around = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }                                          
+	r_distort = GL_FindImage("gfx/water/distort1.tga", it_pic);
+	if (!r_distort) {                                
+		r_distort = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    } 
+	sun_object = R_RegisterGfxPic("sun");
+	if(!sun_object) {
+		sun_object = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+	}
+	sun1_object = R_RegisterGfxPic("sun1");
+	if(!sun1_object) {
+		sun1_object = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+	}
+	sun2_object = R_RegisterGfxPic("sun2");
+	if(!sun2_object) {
+		sun2_object = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+	}
+	r_dis1texture = R_RegisterParticlePic("disbeam1");
+	if (!r_dis1texture) {                                
+		r_dis1texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    } 
+	r_dis2texture = R_RegisterParticlePic("disbeam2");
+	if (!r_dis2texture) {                                
+		r_dis2texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    } 
+	r_dis3texture = R_RegisterParticlePic("disbeam3");
+	if (!r_dis3texture) {                                
+		r_dis3texture = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }    
+ 
 	//
 	// also use this for bad textures, but without alpha
 	//
@@ -248,21 +401,27 @@ void R_InitParticleTexture (void)
 		for (y=0 ; y<16 ; y++)
 		{
 			data[y][x][0] = dottexture[x&3][y&3]*255;
-			data[y][x][1] = 0; // dottexture[x&3][y&3]*255;
-			data[y][x][2] = 0; //dottexture[x&3][y&3]*255;
+			data[y][x][1] = 0; 
+			data[y][x][2] = 0; 
 			data[y][x][3] = 255;
 		}
 	}
 	r_notexture = GL_LoadPic ("***r_notexture***", (byte *)data, 16, 16, it_wall, 32);
 
-	r_cubemap = GL_LoadPic ("***cubemap***", (byte *) pixels, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, it_pic, 32);
-
-	if(gl_cubemaps->value)
-		R_InitCubemapTextures (); 
+	R_InitCubemapTextures (); 
 
+	//will eventually add more flaretypes
 	Com_sprintf (flares, sizeof(flares), "gfx/flares/flare0.tga");
 	r_flare = GL_FindImage(flares, it_pic);
+	if (!r_flare) {                                
+		r_flare = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }     
 
+	Com_sprintf (flares, sizeof(flares), "gfx/flares/flare1.tga");
+	r_flare1 = GL_FindImage(flares, it_pic);
+	if (!r_flare1) {                                
+		r_flare1 = GL_LoadPic ("***particle***", (byte *)data, 16, 16, it_sprite, 32);
+    }   
 }
 
 
@@ -528,13 +687,6 @@ void GL_SetDefaultState( void )
 		qglPointParameterfvEXT( GL_DISTANCE_ATTENUATION_EXT, attenuations );
 	}
 
-	if ( qglColorTableEXT && gl_ext_palettedtexture->value )
-	{
-		qglEnable( GL_SHARED_TEXTURE_PALETTE_EXT );
-
-		GL_SetTexturePalette( d_8to24table );
-	}
-
 	GL_UpdateSwapInterval();
 }
 
