@@ -37,6 +37,9 @@ int		mod_numknown;
 // the inline * models from the current map are kept seperate
 model_t	mod_inline[MAX_MOD_KNOWN];
 
+LightGroup_t LightGroups[MAX_LIGHTS];
+int r_lightgroups;
+
 int		registration_sequence;
 
 #ifdef _WINDOWS
@@ -67,6 +70,73 @@ void Mod_LoadEntityStrn (lump_t *l)
 
 extern char	*CM_EntityString (void);
 
+void R_RegisterLightGroups (void)
+{
+	int			i;
+	vec3_t		dist, mins, maxs;
+	trace_t		r_trace;
+	int			lnum = 0; 
+	qboolean	doneShadowGroups = false;
+	qboolean	lightWasGrouped = false;
+
+	VectorSet(mins, 0, 0, 0);
+	VectorSet(maxs, 0, 0, 0);
+
+	for (i=0; i<r_numWorldLights; i++) { 
+		r_worldLights[i].grouped = false;
+	}
+
+	r_lightgroups = 0;
+
+	while(!doneShadowGroups) {	
+
+		lightWasGrouped = false;
+		for (i=0; i<r_numWorldLights; i++) {
+
+			if(r_worldLights[i].grouped)
+				continue;			
+
+			if(!lnum && !r_worldLights[i].grouped) { //none in group yet, first light establishes the initial origin of the group
+				VectorCopy(r_worldLights[i].origin, LightGroups[r_lightgroups].group_origin);
+				VectorCopy(r_worldLights[i].origin, LightGroups[r_lightgroups].accum_origin);
+				LightGroups[r_lightgroups].avg_intensity = r_worldLights[i].intensity;
+				r_worldLights[i].grouped = true;
+				lnum++;
+				lightWasGrouped = true;
+			}
+
+			VectorSubtract(LightGroups[r_lightgroups].group_origin, r_worldLights[i].origin, dist);
+			r_trace = CM_BoxTrace(LightGroups[r_lightgroups].group_origin, r_worldLights[i].origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
+				
+			if(!r_worldLights[i].grouped && (lnum < r_numWorldLights) && r_trace.fraction == 1.0f && (VectorLength(dist) < 256.0f)) { 
+				r_worldLights[i].grouped = true;
+				VectorAdd(r_worldLights[i].origin, LightGroups[r_lightgroups].accum_origin, LightGroups[r_lightgroups].accum_origin);
+				LightGroups[r_lightgroups].avg_intensity+=(r_worldLights[i].intensity);
+				lnum++;
+				//we grouped an light in this pass
+				lightWasGrouped = true;
+			}		
+		}
+		
+		if(!lightWasGrouped)
+			doneShadowGroups = true;
+		else {
+			//we've reach the end, start a new group
+			if(lnum) {
+				VectorScale(LightGroups[r_lightgroups].accum_origin, 1.0/(float)(lnum), LightGroups[r_lightgroups].accum_origin);
+				LightGroups[r_lightgroups].avg_intensity /= (float)lnum;
+			}
+			VectorCopy(LightGroups[r_lightgroups].accum_origin, LightGroups[r_lightgroups].group_origin);
+			r_lightgroups++;
+			if(r_lightgroups > MAX_LIGHTS) 
+				doneShadowGroups = true;
+	
+			lnum = 0;	
+		}		
+	}
+	Com_Printf("Condensed ^2%i worldlights into ^2%i lightgroups\n", r_numWorldLights, r_lightgroups);
+}
+
 /*
 ================
 R_ParseLightEntities - BERSERK
@@ -85,9 +155,6 @@ static void R_ParseLightEntities (void)
 	vec3_t		origin;
 	float		intensity;
 
-	//DONT LOAD MAP ETS
-//	return;
-
 	entString = map_entitystring;
 
 	buf = CM_EntityString();
@@ -1935,6 +2002,9 @@ void R_BeginRegistration (char *model)
 
 	r_viewcluster = -1;
 
+	r_teamColor = 0;
+	
+	R_RegisterLightGroups();
 }
 
 /*
@@ -2011,6 +2081,9 @@ Mod_Free
 */
 void Mod_Free (model_t *mod)
 {
+	if ( mod->neighbors )
+        free( mod->neighbors );
+
 	Hunk_Free (mod->extradata);
 	memset (mod, 0, sizeof(*mod));
 }
