@@ -561,13 +561,13 @@ void rs_stage_colormap (rs_stage_t *stage, char **token)
 	stage->colormap.enabled = true;
 
 	*token = strtok (NULL, TOK_DELIMINATORS);
-	stage->colormap.red = atoi(*token);
+	stage->colormap.red = atof(*token);
 
 	*token = strtok (NULL, TOK_DELIMINATORS);
-	stage->colormap.green = atoi(*token);
+	stage->colormap.green = atof(*token);
 
 	*token = strtok (NULL, TOK_DELIMINATORS);
-	stage->colormap.blue = atoi(*token);
+	stage->colormap.blue = atof(*token);
 }
 
 void rs_stage_frames (rs_stage_t *stage, char **token)
@@ -1524,8 +1524,8 @@ void R_DrawBeamSurface ( void )
 
 	beam = r_beams;
 
-	VectorSet(mins, 0, 0, 64);
-	VectorSet(maxs, 0, 0, -64);	
+	VectorSet(mins, 32, 32, 64);
+	VectorSet(maxs, -32, -32, -64);	
 
 	R_InitVArrays (VERT_SINGLE_TEXTURED);
 
@@ -1558,6 +1558,7 @@ void R_DrawBeamSurface ( void )
 			qglBlendFunc   (GL_SRC_ALPHA, GL_ONE);	
 
 			qglColor4f( beam->color[0],beam->color[1],beam->color[2], 1 );
+			GL_TexEnv( GL_MODULATE );
 
 			GL_Bind(beam->texnum);
 
@@ -1658,8 +1659,7 @@ void RS_DrawSurfaceTexture (msurface_t *surf, rscript_t *rs)
 	//for envmap by normals
 	AngleVectors (r_newrefdef.viewangles, vectors[0], vectors[1], vectors[2]);
 
-	if(!r_bloom->value) //BLOOMS - this screws with blooms
-		SetVertexOverbrights(true);
+	SetVertexOverbrights(true);
 
 	do
 	{
@@ -1914,8 +1914,7 @@ void RS_DrawSurfaceTexture (msurface_t *surf, rscript_t *rs)
 		
 	} while (stage = stage->next);
 
-	if(!r_bloom->value)
-		SetVertexOverbrights(false);
+	SetVertexOverbrights(false);
 
 	// restore the original blend mode
 	qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
