@@ -26,6 +26,10 @@ SHADOW VOLUMES
 ===============
 */
 
+extern glStencilFuncSeparatePROC	qglStencilFuncSeparate;
+extern glStencilOpSeparatePROC		qglStencilOpSeparate;
+extern glStencilMaskSeparatePROC	qglStencilMaskSeparate;
+
 vec3_t ShadowArray[MAX_SHADOW_VERTS];
 static qboolean	triangleFacingLight	[MAX_INDICES / 3];
 
@@ -372,99 +376,78 @@ void GL_RenderVolumes(dmdl_t * paliashdr, vec3_t lightdir, int projdist, qboolea
 
 void GL_DrawAliasShadowVolume(dmdl_t * paliashdr, qboolean lerp)
 {
-	vec3_t light, temp;
-	int i, o;
-	dlight_t *dl;
-	worldLight_t *wl;
+	vec3_t light, temp, tempOrg;
+	int i, j, o;
 	float cost, sint;
 	float is, it, dist;
-	int worldlight = 0, dlight = 0;
+	int worldlight = 0;
+	float numlights, weight;
+	float bob, project;
 	trace_t	r_trace;
-	vec3_t mins, maxs;
+	vec3_t mins, maxs, lightAdd;
 	
 	VectorSet(mins, 0, 0, 0);
 	VectorSet(maxs, 0, 0, 0);
-	
-	dl = r_newrefdef.dlights;
 
 	if (r_newrefdef.vieworg[2] < (currententity->origin[2] - 10))
 		return;
 
 	if (r_newrefdef.rdflags & RDF_NOWORLDMODEL)
 		return;
+
+	if(currententity->flags & RF_BOBBING) 
+		bob = currententity->bob;
+	else
+		bob = 0;
+
+	VectorCopy(currententity->origin, tempOrg);
+	tempOrg[2] -= bob;
 	
 	VectorClear(light);
 	
 	cost =  cos(-currententity->angles[1] / 180 * M_PI), 
     sint =  sin(-currententity->angles[1] / 180 * M_PI);
-
-	for (i = 0; i < (r_newrefdef.num_dlights > 5 ? 5: r_newrefdef.num_dlights); i++, dl++) {
-
-		if ((dl->origin[0] == currententity->origin[0]) &&
-			(dl->origin[1] == currententity->origin[1]) &&
-		    (dl->origin[2] == currententity->origin[2]))
-		        continue;
-
-		//need a trace
-		r_trace = CM_BoxTrace(currententity->origin, dl->origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
-		if(r_trace.fraction != 1.0)
-			continue;
-
-		VectorSubtract(currententity->origin, dl->origin, temp);
-		dist = VectorLength(temp);
-
-		if (dist > dl->intensity*2.0)
-			continue;		// big distance! - but check this so we dont' have sharp shadow loss
-
-		VectorCopy(dl->origin, temp);
-
-		for (o = 0; o < 3; o++)
-			light[o] = -currententity->origin[o] + temp[o];	
-
-		is = light[0], it = light[1];
-		light[0] = (cost * (is - 0) + sint * (0 - it) + 0);
-		light[1] = (cost * (it - 0) + sint * (is - 0) + 0);
-		light[2] += currententity->model->maxs[2]+32;
 	
-		worldlight++;
-		dlight++;
-	}
+	numlights = 0;
+	VectorClear(lightAdd);
+	for (i=0; i<r_lightgroups; i++) {	
 
-	if(dlight)
-		GL_RenderVolumes(paliashdr, light, 15, lerp);
-
-	for (i=0; i<r_numWorldLights; i++) {
-
-		wl = &r_worldLights[i];
-
-		if(wl->origin[2] < currententity->origin[2])
+		if(LightGroups[i].group_origin[2] < currententity->origin[2] - bob)
 			continue; //don't bother with world lights below the ent, creates undesirable shadows
 
-		//need a trace
-		r_trace = CM_BoxTrace(currententity->origin, wl->origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
-		if(r_trace.fraction != 1.0)
-			continue;
+		//need a trace(not for self model, too jerky when lights are blocked and reappear)
+		if(!(currententity->flags & RF_VIEWERMODEL)) {
+			r_trace = CM_BoxTrace(tempOrg, LightGroups[i].group_origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
+			if(r_trace.fraction != 1.0)
+				continue;
+		}
 
-		VectorSubtract(wl->origin, currententity->origin, temp);
+		VectorSubtract(LightGroups[i].group_origin, currententity->origin, temp);
 
 		dist = VectorLength(temp);
-
-		if (dist > 1500)
-			continue;		// big distance!
-						
-		for (o = 0; o < 3; o++)
-			light[o] = -currententity->origin[o] + wl->origin[o];	
-		
-		is = light[0], it = light[1];
-		light[0] = (cost * (is - 0) + sint * (0 - it) + 0);
-		light[1] = (cost * (it - 0) + sint * (is - 0) + 0);
-		light[2] += currententity->model->maxs[2] + 56;
-
-		worldlight++;
+				
+		//accum and weight
+		weight = (int)250000/(dist/(LightGroups[i].avg_intensity+1.0f));
+		for(j = 0; j < 3; j++) 
+			lightAdd[j] += LightGroups[i].group_origin[j]*weight;
+		numlights+=weight;
 			
+		if(numlights > 0.0) {
+
+			for(o = 0; o < 3; o++) 
+				light[o] = -currententity->origin[o] + lightAdd[o]/numlights;
+
+			is = light[0], it = light[1];
+			light[0] = (cost * (is - 0) + sint * (0 - it) + 0);
+			light[1] = (cost * (it - 0) + sint * (is - 0) + 0);
+			light[2] += currententity->model->maxs[2] + 56;
+		}	
+
+		worldlight++;		
 	}
+
 	
-	if (!worldlight) {
+	if(!worldlight) { //no lights found, create light straight down
 
 		VectorSet(light, 0, 0, 200);
 	
@@ -473,8 +456,13 @@ void GL_DrawAliasShadowVolume(dmdl_t * paliashdr, qboolean lerp)
 		light[1] = (cost * (it - 0) + sint * (is - 0) + 0);
 		light[2] += 8;
 	}
+
+	if(currentmodel->maxs[2] - currentmodel->mins[2] > 200)
+		project = 2.0;
+	else
+		project = 1.5;
 	
-	GL_RenderVolumes(paliashdr, light, 15, lerp);
+	GL_RenderVolumes(paliashdr, light, project, lerp);
 }
 
 /*==============
@@ -610,3 +598,222 @@ void R_DrawShadowVolume(entity_t * e)
 	qglPopMatrix();
 }
 
+
+void R_CastShadow(void)
+{
+	int i;
+	vec3_t dist;
+	
+	//note - we use a combination of stencil volumes(for world light shadows) and shadowmaps(for dynamic shadows)
+	if (!gl_shadowmaps->value)
+		return;
+		
+	qglEnableClientState(GL_VERTEX_ARRAY);
+	qglVertexPointer(3, GL_FLOAT, sizeof(vec3_t), ShadowArray);
+
+	qglClear(GL_STENCIL_BUFFER_BIT);
+
+	qglColorMask(0,0,0,0);
+	qglEnable(GL_STENCIL_TEST);
+	
+	qglDepthFunc (GL_LESS);
+	qglDepthMask(0);
+
+	qglEnable(GL_POLYGON_OFFSET_FILL);
+	qglPolygonOffset(0.0f, 100.0f);
+
+	if(gl_state.separateStencil)
+		qglStencilFuncSeparate(GL_FRONT_AND_BACK, GL_ALWAYS, 0x0, 0xFF);
+	else
+		qglStencilFunc( GL_ALWAYS, 0x0, 0xFF);
+
+	for (i = 0; i < r_newrefdef.num_entities; i++) 
+	{
+		currententity = &r_newrefdef.entities[i];
+
+		if (currententity->flags & RF_TRANSLUCENT)
+			continue;	// transluscent
+
+		currentmodel = currententity->model; 
+
+		if (!currentmodel)
+			continue;
+		
+		if (currentmodel->type != mod_alias)
+			continue;
+
+		//get distance, set lod if available
+		VectorSubtract(r_origin, currententity->origin, dist);
+		if(VectorLength(dist) > 1000) {
+			if(currententity->lod2)
+				currentmodel = currententity->lod2;
+		}
+		else if(VectorLength(dist) > 500) {
+			if(currententity->lod1) 
+				currentmodel = currententity->lod1;
+		}
+
+		if (currententity->
+		flags & (RF_SHELL_HALF_DAM | RF_SHELL_GREEN | RF_SHELL_RED |
+				 RF_SHELL_BLUE | RF_SHELL_DOUBLE |
+				 RF_WEAPONMODEL | RF_NOSHADOWS))
+				 continue;
+		
+		R_DrawShadowVolume(currententity);
+	}
+
+	qglDisableClientState(GL_VERTEX_ARRAY);
+	qglColorMask(1,1,1,1);
+	
+	qglDepthMask(1);
+	qglDepthFunc(GL_LEQUAL);
+	
+	R_ShadowBlend(0.3);   
+
+}
+
+
+/*
+===============
+R_ShadowLight - Planar stencil shadows
+===============
+*/
+void vectoangles (vec3_t value1, vec3_t angles)
+{
+	float	forward;
+	float	yaw, pitch;
+
+	if (value1[1] == 0 && value1[0] == 0)
+	{
+		yaw = 0;
+		if (value1[2] > 0)
+			pitch = 90;
+		else
+			pitch = 270;
+	}
+	else
+	{
+	// PMM - fixed to correct for pitch of 0
+		if (value1[0])
+			yaw = (atan2(value1[1], value1[0]) * 180 / M_PI);
+		else if (value1[1] > 0)
+			yaw = 90;
+		else
+			yaw = 270;
+
+		if (yaw < 0)
+			yaw += 360;
+
+		forward = sqrt (value1[0]*value1[0] + value1[1]*value1[1]);
+		pitch = (atan2(value1[2], forward) * 180 / M_PI);
+		if (pitch < 0)
+			pitch += 360;
+	}
+
+	angles[PITCH] = -pitch;
+	angles[YAW] = yaw;
+	angles[ROLL] = 0;
+}
+
+float R_ShadowLight (vec3_t entPos, vec3_t lightAdd, int type)
+{
+	int			lnum, i;
+	dlight_t	*dl;
+	vec3_t		pos, dist, angle, mins, maxs;
+	trace_t		r_trace;
+	float		add, shadowdist, bob;
+	float   	intens = 0;
+
+	if (!r_worldmodel)
+		return 0;
+	if (!r_worldmodel->lightdata) //keep old lame shadow
+		return 0;
+
+	VectorCopy(entPos, pos);
+
+	VectorSet(mins, 0, 0, 0);
+	VectorSet(maxs, 0, 0, 0);
+
+	VectorClear(lightAdd);
+	//
+	// add dynamic light shadow angles
+	//
+	if(!type) {
+		dl = r_newrefdef.dlights;
+		for (lnum=0; lnum<r_newrefdef.num_dlights; lnum++, dl++)
+		{
+
+			VectorSubtract (dl->origin, pos, dist);
+			add = sqrt(dl->intensity - VectorLength(dist));
+			VectorNormalize(dist);
+			if (add > 0)
+			{
+				VectorScale(dist, add, dist);
+				VectorAdd (lightAdd, dist, lightAdd);
+				intens = 0.3;
+			}
+		}
+	}
+	//
+	// add world light shadow angles
+	//
+	if(currententity->flags & RF_BOBBING) 
+		bob = currententity->bob;
+	else
+		bob = 0;
+
+	pos[2] -= bob;
+
+	if(gl_shadows->integer == 2 && type) {
+
+		for (i=0; i<r_lightgroups; i++) {
+
+			if(LightGroups[i].group_origin[2] < currententity->origin[2] - bob)
+				continue; //don't bother with world lights below the ent, creates undesirable shadows
+
+			//need a trace(not for self model, too jerky when lights are blocked and reappear)
+			if(!(currententity->flags & RF_VIEWERMODEL)) {
+				r_trace = CM_BoxTrace(pos, LightGroups[i].group_origin, mins, maxs, r_worldmodel->firstnode, MASK_OPAQUE);
+				if(r_trace.fraction != 1.0)
+					continue;
+			}
+			
+			VectorSubtract (LightGroups[i].group_origin, pos, dist);
+			add = sqrt(LightGroups[i].avg_intensity*50.0f - VectorLength(dist));
+			VectorNormalize(dist);
+			if (add > 0) 
+			{
+				VectorScale(dist, sqrt(add), dist);
+				VectorAdd (lightAdd, dist, lightAdd);
+				intens+=(LightGroups[i].avg_intensity - VectorLength(dist)*3.5f); //darken shadows where light is stronger
+			}
+		}
+
+		//cap some limits of lightness, darkness, subtley.
+		if (intens < 0.1)
+			intens = 0.1;
+		if (intens > 0.3)
+			intens = 0.3;
+	}
+
+	// Barnes improved code
+	shadowdist = VectorNormalize(lightAdd)/5.0;
+	if (shadowdist > 4) shadowdist = 4;
+	if (shadowdist <= 0) // old style static shadow
+	{
+		angle[PITCH] = currententity->angles[PITCH];
+		angle[YAW] =   -currententity->angles[YAW];
+		angle[ROLL] =   currententity->angles[ROLL];
+		shadowdist = 1;
+	}
+	else // shadow from dynamic lights
+	{
+		vectoangles (lightAdd, angle);
+		angle[YAW] -= currententity->angles[YAW];
+	}
+	AngleVectors (angle, dist, NULL, NULL);
+	VectorScale (dist, shadowdist, lightAdd);
+	// end Barnes improved code
+
+	return intens;
+}
