@@ -121,6 +121,102 @@ void DrawGLPoly (msurface_t *fa, int flags)
 
 }
 
+/*
+================
+DrawGLTexturelessPoly
+================
+*/
+void DrawGLTexturelessPoly (msurface_t *fa)
+{	
+
+	R_InitVArrays(VERT_NO_TEXTURE);
+	R_AddSurfToVArray (fa);
+	R_KillVArrays();
+
+}
+
+void R_DrawTexturelessInlineBModel (entity_t *e)
+{
+	int			i;
+	msurface_t	*psurf;
+
+	//
+	// draw texture
+	//
+	psurf = &currentmodel->surfaces[currentmodel->firstmodelsurface];
+	for (i=0 ; i<currentmodel->nummodelsurfaces ; i++, psurf++)
+	{
+
+	// draw the polygon
+		DrawGLTexturelessPoly( psurf );
+		psurf->visframe = r_framecount;
+	}
+
+	qglDisable (GL_BLEND);
+	qglColor4f (1,1,1,1);
+	GL_TexEnv( GL_REPLACE );	
+}
+
+void R_DrawTexturelessBrushModel (entity_t *e)
+{
+	vec3_t		mins, maxs;
+	int			i;
+	qboolean	rotated;
+
+	if (currentmodel->nummodelsurfaces == 0)
+		return;
+
+	currententity = e;
+
+	if (e->angles[0] || e->angles[1] || e->angles[2])
+	{
+		rotated = true;
+		for (i=0 ; i<3 ; i++)
+		{
+			mins[i] = e->origin[i] - currentmodel->radius;
+			maxs[i] = e->origin[i] + currentmodel->radius;
+		}
+	}
+	else
+	{
+		rotated = false;
+		VectorAdd (e->origin, currentmodel->mins, mins);
+		VectorAdd (e->origin, currentmodel->maxs, maxs);
+	}
+
+	if (R_CullBox (mins, maxs)) {
+		return;
+	}
+
+	qglColor3f (1,1,1);
+
+	VectorSubtract (r_newrefdef.vieworg, e->origin, modelorg);
+
+	if (rotated)
+	{
+		vec3_t	temp;
+		vec3_t	forward, right, up;
+
+		VectorCopy (modelorg, temp);
+		AngleVectors (e->angles, forward, right, up);
+		modelorg[0] = DotProduct (temp, forward);
+		modelorg[1] = -DotProduct (temp, right);
+		modelorg[2] = DotProduct (temp, up);
+	}
+
+    qglPushMatrix ();
+	e->angles[0] = -e->angles[0];	// stupid quake bug
+	e->angles[2] = -e->angles[2];	// stupid quake bug
+	R_RotateForEntity (e);
+	e->angles[0] = -e->angles[0];	// stupid quake bug
+	e->angles[2] = -e->angles[2];	// stupid quake bug
+
+	R_DrawTexturelessInlineBModel (e);
+
+	qglPopMatrix ();
+}
+
+
 /*
 ** R_DrawTriangleOutlines
 */
@@ -762,6 +858,8 @@ dynamic:
 			qglActiveTextureARB(GL_TEXTURE3);
 			qglBindTexture(GL_TEXTURE_2D, surf->texinfo->normalMap->texnum);
 			KillFlags |= KILL_TMU3_POINTER;
+
+			glUniform1iARB( g_location_shadowmap, 0); //static light shadow handled by stencil volumes
 			
 			if(is_dynamic) {
 						
@@ -773,28 +871,29 @@ dynamic:
 					glUniform1fARB( g_location_lightCutoffSquared, lightCutoffSquared);
 					
 					glUniform1iARB( g_location_dynamic, 1);
-					if(gl_shadowmaps->value) { //dynamic world shadows
+
+					if(gl_shadowmaps->value) { 
+						
+						//dynamic shadow
 						glUniform1iARB( g_location_bspShadowmapTexture, 7);
 						qglActiveTextureARB(GL_TEXTURE7);
 						qglBindTexture(GL_TEXTURE_2D, r_depthtexture->texnum);
+
 						glUniform1iARB( g_location_shadowmap, 1);
 					}
+					else
+						glUniform1iARB( g_location_shadowmap, 0);
 				}
 				else {
 					glUniform1iARB( g_location_dynamic, 0);
-					glUniform1iARB( g_location_shadowmap, 0);
 				}
 			}
 			else 
 				glUniform1iARB( g_location_dynamic, 0);
 				
 			glUniform1iARB( g_location_parallax, 1);
-			if(gl_specular->value)
-				glUniform1iARB( g_location_specular, 1);
-			else
-				glUniform1iARB( g_location_specular, 0);
-			
-			R_AddGLSLShadedSurfToVArray (surf, scroll, true);
+						
+			R_AddGLSLShadedSurfToVArray (surf, scroll);
 
 			glUseProgramObjectARB( 0 );
 
@@ -822,12 +921,17 @@ dynamic:
 			qglBindTexture(GL_TEXTURE_2D, surf->texinfo->normalMap->texnum);
 			KillFlags |= KILL_TMU3_POINTER;
 
-			if(gl_shadowmaps->value) { //dynamic world shadows
+			if(gl_shadowmaps->value) { 
+				
+				//dynamic shadow
 				glUniform1iARB( g_location_bspShadowmapTexture, 7);
 				qglActiveTextureARB(GL_TEXTURE7);
 				qglBindTexture(GL_TEXTURE_2D, r_depthtexture->texnum);
+
 				glUniform1iARB( g_location_shadowmap, 1);
 			}
+			else
+				glUniform1iARB( g_location_shadowmap, 0);
 	
 			glUniform3fARB( g_location_lightPosition, dl->origin[0], dl->origin[1], dl->origin[2]);
 			glUniform3fARB( g_location_lightColour, dl->color[0], dl->color[1], dl->color[2]);
@@ -835,11 +939,11 @@ dynamic:
 			glUniform1iARB( g_location_dynamic, 1);
 			glUniform1iARB( g_location_parallax, 0);
 			
-			R_AddGLSLShadedSurfToVArray (surf, scroll, true);
+			R_AddGLSLShadedSurfToVArray (surf, scroll);
 
 			glUseProgramObjectARB( 0 );
 
-		}
+		}		
 		//surface has no normalmap
 		else {
 		
