@@ -20,7 +20,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // r_warp.c -- sky and water polygons
 
 #include "r_local.h"
-#include "r_refl.h"	// MPO
 
 extern	model_t	*loadmodel;
 
@@ -32,7 +31,6 @@ image_t	*sky_images[6];
 msurface_t	*warpface;
 
 #define	SUBDIVIDE_SIZE	64
-//#define	SUBDIVIDE_SIZE	1024
 
 void BoundPoly (int numverts, float *verts, vec3_t mins, vec3_t maxs)
 {
@@ -200,8 +198,8 @@ float	r_turbsin[] =
 {
 	#include "warpsin.h"
 };
-#define TURBSCALE (256.0 / (2 * M_PI))
-#define TURBOSCALE (256.0f / ((float)M_PI / 4.0f)) // jitwater / dukey
+
+#define TURBOSCALE (256.0f / ((float)M_PI / 4.0f))
 
 /*
 =============
@@ -210,7 +208,9 @@ EmitWaterPolys
 Does a water warp on the pre-fragmented glpoly_t chain
 =============
 */
-void EmitWaterPolys_original (msurface_t *fa)	//MPO renamed
+
+extern int KillFlags;
+void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY)
 {
 	glpoly_t	*p;
 	float		*v;
@@ -218,86 +218,86 @@ void EmitWaterPolys_original (msurface_t *fa)	//MPO renamed
 	float		s, t, os, ot;
 	float		scroll;
 	float		rdt = r_newrefdef.time;
-	vec3_t		nv, vectors[3];   // Water waves
-	
+	vec3_t		nv;  
+	qboolean	fod;
+
 	if (fa->texinfo->flags & SURF_FLOWING)
-		scroll = -64 * ( (r_newrefdef.time*0.5) - (int)(r_newrefdef.time*0.5) );
+		scroll = -64.0f * ((r_newrefdef.time * 0.5f) - (int)(r_newrefdef.time * 0.5f));
 	else
-		scroll = 0;
+		scroll = 0.0f;
+	
+	//special case - note one day we should find a way to check for contents such as mist to do this.
+	if(!Q_stricmp(fa->texinfo->image->name, "textures/arena6/fodblue.wal") || !Q_stricmp(fa->texinfo->image->name, "textures/arena5/fod.wal"))
+		fod = true;
+	else
+		fod = false;
 
-	for (p=fa->polys ; p ; p=p->next)
-	{
-		qglBegin (GL_TRIANGLE_FAN);
-		for (i=0,v=p->verts[0] ; i<p->numverts ; i++, v+=VERTEXSIZE)
-		{
-			os = v[3];
-			ot = v[4];
-
-#if !id386
-			s = os + r_turbsin[(int)((ot*0.125+r_newrefdef.time) * TURBSCALE) & 255];
-#else
-			s = os + r_turbsin[Q_ftol( ((ot*0.125+rdt) * TURBSCALE) ) & 255];
-#endif
-			s += scroll;
-			s *= (1.0/64);
-
-#if !id386
-			t = ot + r_turbsin[(int)((os*0.125+rdt) * TURBSCALE) & 255];
-#else
-			t = ot + r_turbsin[Q_ftol( ((os*0.125+rdt) * TURBSCALE) ) & 255];
-#endif
-			t *= (1.0/64);
+	if(!fod && gl_state.glsl_shaders && gl_glsl_shaders->value  
+			&& strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name)) {
 		
-			qglTexCoord2f (s, t);
-//=============== Water waves ============
+		if (SurfaceIsAlphaBlended(fa))
+			qglEnable( GL_ALPHA_TEST );
 
-			if (!(fa->texinfo->flags & SURF_FLOWING))
+		R_InitVArrays (VERT_NORMAL_COLOURED_TEXTURED);
 
-			{
+		glUseProgramObjectARB( g_waterprogramObj );
 
-				nv[0] =v[0];
+		GL_EnableMultitexture( true );
+    	
+		qglActiveTextureARB(GL_TEXTURE1);
+		qglBindTexture (GL_TEXTURE_2D, fa->texinfo->image->texnum);
+		glUniform1iARB( g_location_baseTexture, 1); 
+		KillFlags |= KILL_TMU1_POINTER;
 
-				nv[1] =v[1];
+		glUniform1iARB( g_location_normTexture, 2);
+		qglActiveTextureARB(GL_TEXTURE2);
+		qglBindTexture(GL_TEXTURE_2D, fa->texinfo->normalMap->texnum);
+		KillFlags |= KILL_TMU2_POINTER;
 
-				#if !id386
+		if(fa->texinfo->flags &(SURF_TRANS33|SURF_TRANS66))
+			glUniform1iARB( g_location_trans, 1);
+		else
+			glUniform1iARB( g_location_trans, 0);
 
-				nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+r_newrefdef.time)*sin(v[2]*0.05+r_newrefdef.time)
-
-						+ r_wave->value *sin(v[1]*0.025+r_newrefdef.time*2)*sin(v[2]*0.05+r_newrefdef.time);
-
-				#else
-
-				nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+rdt)*sin(v[2]*0.05+r_newrefdef.time)
-
-						+ r_wave->value *sin(v[1]*0.025+rdt*2)*sin(v[2]*0.05+rdt);
-
-				#endif
-
-
-
-				qglVertex3fv (nv);
-
-			}
-
-			else
-
-//============= Water waves end. ==============
-
-
-			qglVertex3fv (v);
+		if(texnum) {
+			qglActiveTextureARB(GL_TEXTURE3);
+			qglBindTexture(GL_TEXTURE_2D, texnum);
+			glUniform1iARB( g_location_refTexture, 3); 
+			glUniform1iARB( g_location_reflect, 1);
 		}
-		qglEnd ();
+		else
+			glUniform1iARB( g_location_reflect, 0);
+			
+		R_AddGLSLShadedWarpSurfToVArray (fa, scroll);
+
+		glUseProgramObjectARB( 0 );
+
+		R_KillVArrays ();
+
+		GL_EnableMultitexture( false );
+
+		if (SurfaceIsAlphaBlended(fa))
+			qglDisable( GL_ALPHA_TEST);
+
+		GL_MBind(GL_TEXTURE0, fa->texinfo->image->texnum);
 	}
+	else {
 
-	//env map for certain waters(more clear types)
-	if(fa->texinfo->flags &(SURF_TRANS33)){
-
-		//hack for stock fog textures, ugh
-		if(!Q_stricmp(fa->texinfo->image->name, "textures/arena6/fodblue.wal") || !Q_stricmp(fa->texinfo->image->name, "textures/arena5/fod.wal"))
-			return;
-
-		AngleVectors (r_newrefdef.viewangles, vectors[0], vectors[1], vectors[2]);
-		GL_Bind(r_reflecttexture->texnum);
+		if (gl_state.fragment_program && !fod)
+		{
+			qglEnable(GL_FRAGMENT_PROGRAM_ARB);
+			qglBindProgramARB(GL_FRAGMENT_PROGRAM_ARB, g_water_program_id);
+			qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 0,
+				rs_realtime * (0.2f), 1.0f, 1.0f, 1.0f);
+			qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 1,
+				rs_realtime * -0.2f, 10.0f, 1.0f, 1.0f);
+			qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 2,
+				(fa->polys[0].verts[0][3]-r_newrefdef.vieworg[0]), (fa->polys[0].verts[0][4]-r_newrefdef.vieworg[1]), (fa->polys[0].verts[0][4]-r_newrefdef.vieworg[2]), 1.0f);
+			
+			GL_MBind(GL_TEXTURE1, r_distort->texnum); 
+		}
+		
+		GL_MBind(GL_TEXTURE0, fa->texinfo->image->texnum);
 
 		for (p=fa->polys ; p ; p=p->next)
 		{
@@ -307,278 +307,98 @@ void EmitWaterPolys_original (msurface_t *fa)	//MPO renamed
 				os = v[3];
 				ot = v[4];
 
-				RS_SetEnvmap (v, &os, &ot);
-					//move by normal & position
-				os-=DotProduct (fa->plane->normal, vectors[1] ) + (r_newrefdef.vieworg[0]-r_newrefdef.vieworg[1]+r_newrefdef.vieworg[2])*0.0025;
-				ot+=DotProduct (fa->plane->normal, vectors[2] ) + (-r_newrefdef.vieworg[0]+r_newrefdef.vieworg[1]-r_newrefdef.vieworg[2])*0.0025;
-				
+	#if !id386
+				s = os + r_turbsin[(int)((ot*0.125+r_newrefdef.time) * TURBSCALE) & 255];
+	#else
+				s = os + r_turbsin[Q_ftol( ((ot*0.125+rdt) * TURBSCALE) ) & 255];
+	#endif
+				s += scroll;
+				s *= (1.0/64);
+
+	#if !id386
+				t = ot + r_turbsin[(int)((os*0.125+rdt) * TURBSCALE) & 255];
+	#else
+				t = ot + r_turbsin[Q_ftol( ((os*0.125+rdt) * TURBSCALE) ) & 255];
+	#endif
+				t *= (1.0/64);
+
+				if (gl_state.fragment_program && !fod)
+				{
+					qglMTexCoord2fSGIS(GL_TEXTURE0, s, t);
+					qglMTexCoord2fSGIS(GL_TEXTURE1, 20*s, 20*t);
+				}
+				else
+					qglTexCoord2f (s, t);
 
-				qglTexCoord2f (.5*os, .5*ot);
-				
 				if (!(fa->texinfo->flags & SURF_FLOWING))
 
 				{
 
 					nv[0] =v[0];
-
 					nv[1] =v[1];
 
 					#if !id386
-
 					nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+r_newrefdef.time)*sin(v[2]*0.05+r_newrefdef.time)
 
 							+ r_wave->value *sin(v[1]*0.025+r_newrefdef.time*2)*sin(v[2]*0.05+r_newrefdef.time);
-
 					#else
-
 					nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+rdt)*sin(v[2]*0.05+r_newrefdef.time)
 
 							+ r_wave->value *sin(v[1]*0.025+rdt*2)*sin(v[2]*0.05+rdt);
-
 					#endif
-
-
-
 					qglVertex3fv (nv);
-
 				}
-
 				else
-
-				qglVertex3fv (v);
+					qglVertex3fv (v);
 			}
 			qglEnd ();
 		}
-	}
-}
 
-
-float CalcWave (float x, float y) // jitwater / MPO
-{
-	return (r_turbsin[(int)((x*3+r_newrefdef.time) * TURBOSCALE) & 255] / 2.0f) + 
-		(r_turbsin[(int)((y*5+r_newrefdef.time) * TURBOSCALE) & 255] / 2.0f);
-}
-
-// === jitwater
-extern image_t *distort_tex;
-extern image_t *water_normal_tex;
-// MPO : this is my version...
-void EmitWaterPolys (msurface_t *fa)
-{
-	//==============================
-	glpoly_t	*p;
-	glpoly_t	*bp;
-	float		*v;
-	int			i;
-	float		s; 
-	float		t; 
-	float		os; 
-	float		ot;
-	float		scroll;
-	float		rdt = r_newrefdef.time;
-	float		zValue = 0.0;			// height of water
-	qboolean	waterNotFlat = false;
-	qboolean	flowing;
-	//==============================
-
-	if (g_drawing_refl)
-		return;	// we don't want any water drawn while we are doing our reflection
-
-	if (fa->texinfo->flags & SURF_FLOWING)
-	{
-		scroll = -64.0f * ((r_newrefdef.time * 0.5f) - (int)(r_newrefdef.time * 0.5f));
-		flowing = true;
-	}
-	else
-	{
-		scroll = 0.0f;
-		flowing = false;
+		if (gl_state.fragment_program && !fod)
+			qglDisable(GL_FRAGMENT_PROGRAM_ARB);
 	}
 
-	// skip the water texture on transparent surfaces
-	if (gl_reflection->value && (fa->texinfo->flags & (SURF_TRANS33|SURF_TRANS66)))
-	{
-		for (bp = fa->polys; bp; bp = bp->next)
-		{
-			p = bp;
-
-			for (i=0, v=p->verts[0]; i < p->numverts; i++, v += VERTEXSIZE)
-			{
-				// if it hasn't been initalized before
-				if (zValue == 0.0f)
-					zValue = v[2];
-
-				// Make sure polygons are on the same plane
-				// Fix for not perfectly flat water on base1 - strange ..
-				else if (fabs(zValue - v[2]) > 8.0f)
-					waterNotFlat = true;
-			}
-		}
-	}
-
-	if (waterNotFlat || !gl_reflection->value || !(fa->texinfo->flags & (SURF_TRANS33|SURF_TRANS66)))
-	{
-		for (bp = fa->polys; bp; bp = bp->next)
-		{
-			p = bp;
-			qglBegin(GL_TRIANGLE_FAN);
-
-			for (i=0, v=p->verts[0]; i < p->numverts; i++, v += VERTEXSIZE)
-			{
-				os = v[3]; 
-				ot = v[4];
-
-				#if !id386
-				s = os + r_turbsin[(int)((ot*0.125+r_newrefdef.time) * TURBSCALE) & 255];
-				#else
-				s = os + r_turbsin[Q_ftol(((ot*0.125+rdt) * TURBSCALE)) & 255];
-				#endif
-
-				s += scroll;
-				s *= (1.0/64);
-
-				#if !id386
-				t = ot + r_turbsin[(int)((os*0.125+rdt) * TURBSCALE) & 255];
-				#else
-				t = ot + r_turbsin[Q_ftol(((os*0.125+rdt) * TURBSCALE)) & 255];
-				#endif
-				t *= (1.0f / 64.0f);
-
-				// if it hasn't been initalized before
-				if (zValue == 0.0f)
-					zValue = v[2];
-
-				// Make sure polygons are on the same plane
-				// Fix for not perfectly flat water on base1 - strange ..
-				else if (fabs(zValue - v[2]) > 0.1f)
-					waterNotFlat = true;
-
-				qglTexCoord2f(s, t);
-				qglVertex3f(v[0], v[1], v[2]);
-			}
-
-			qglEnd();
-		} 
-	}
-
-	if (waterNotFlat)
+	if(fod || (gl_state.glsl_shaders && gl_glsl_shaders->value))
 		return;
 
-	if (gl_reflection->value)
-	{
-		//====================
-		vec3_t	distanceVector;
-		float	distance;
-		//====================
-
-		v = p->verts[0];
-		VectorSubtract(v, r_newrefdef.vieworg, distanceVector);
-		distance = VectorLength(distanceVector);
-		//R_add_refl(zValue, distance);
-		R_add_refl(v[0], v[1], zValue);
-		g_refl_enabled = true;
-	}
-
-	// find out which reflection we have that corresponds to the surface that we're drawing	
-	for (g_active_refl = 0; g_active_refl < g_num_refl; g_active_refl++)
-	{
-		// if we find which reflection to bind
-		if (fabs(g_refl_Z[g_active_refl] - zValue) < 8.0f)
-		{
-			// === jitwater
-			if (gl_state.fragment_program)
-			{
-				qglEnable(GL_FRAGMENT_PROGRAM_ARB);
-				qglBindProgramARB(GL_FRAGMENT_PROGRAM_ARB, g_water_program_id);
-				qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 0,
-					rs_realtime * (flowing ? -0.3f : 0.2f), 1.0f, 1.0f, 1.0f);
-				qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 1,
-					rs_realtime * -0.2f, 10.0f, 1.0f, 1.0f);
-				qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 2,
-					r_newrefdef.vieworg[0], r_newrefdef.vieworg[1], r_newrefdef.vieworg[2], 1.0f);
-				if(distort_tex)
-					GL_MBind(GL_TEXTURE2, distort_tex->texnum);      // Distortion texture
-				if(water_normal_tex)
-					GL_MBind(GL_TEXTURE1, water_normal_tex->texnum); // Normal texture
-			}
-
-			GL_MBind(GL_TEXTURE0, g_tex_num[g_active_refl]); // Reflection texture
-			// jitwater ===
-
-			break;
-		}
-	}
-
-	// if we found a reflective surface correctly, then go ahead and draw it
-	if (g_active_refl != g_num_refl)
-	{
-		qglColor4f(1.0f, 1.0f, 1.0f, 1.0f);
+	//env map if specified by shader
+	if(texnum)
+		GL_Bind(texnum);
+	else 
+		return;
 		
-		if (!gl_state.blend)
-			qglEnable(GL_BLEND);
+	for (p=fa->polys ; p ; p=p->next)
+	{
+		qglBegin (GL_TRIANGLE_FAN);
+		for (i=0,v=p->verts[0] ; i<p->numverts ; i++, v+=VERTEXSIZE)
+		{
+			os = v[3] - r_newrefdef.vieworg[0] + 128*scaleX;
+			ot = v[4] + r_newrefdef.vieworg[1] + 128*scaleY;
 
-		GL_TexEnv(GL_MODULATE);
-		qglShadeModel(GL_SMOOTH);
-		R_LoadReflMatrix();
-
-  		// draw reflected water layer on top of regular
-  		for (bp = fa->polys; bp; bp = bp->next)
-  		{
-			p = bp;
-			qglBegin(GL_TRIANGLE_FAN);
-
-			for (i=0, v=p->verts[0]; i < p->numverts; i++, v+=VERTEXSIZE)
-			{
-				if (gl_state.fragment_program)
-				{
-					qglMultiTexCoord3fvARB(GL_TEXTURE0, v);
-					qglMultiTexCoord3fvARB(GL_TEXTURE1, v);
-					qglMultiTexCoord3fvARB(GL_TEXTURE2, v);
-				}
-				else
-				{
-					vec3_t	vAngle;
-
-					qglTexCoord3f(v[0], v[1] + CalcWave(v[0], v[1]), v[2]);
+			if(texnum)
+				qglTexCoord2f(1.0/512*scaleX*os, 1.0/512*scaleY*ot);
 				
-					if (r_newrefdef.rdflags & RDF_UNDERWATER)
-					{
-						VectorSubtract(v, r_newrefdef.vieworg, vAngle);
-						VectorNormalize(vAngle);
+			if (!(fa->texinfo->flags & SURF_FLOWING))
+			{
+				nv[0] =v[0];
+				nv[1] =v[1];
 
-						if (vAngle[2] > 0.55f)
-							vAngle[2] = 0.55f;
+				#if !id386
+				nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+r_newrefdef.time)*sin(v[2]*0.05+r_newrefdef.time)
+						+ r_wave->value *sin(v[1]*0.025+r_newrefdef.time*2)*sin(v[2]*0.05+r_newrefdef.time);
+				#else
+				nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+rdt)*sin(v[2]*0.05+r_newrefdef.time)
+						+ r_wave->value *sin(v[1]*0.025+rdt*2)*sin(v[2]*0.05+rdt);
+				#endif
 
-						qglColor4f(1.0f, 1.0f, 1.0f, 0.9f - (vAngle[2] * 1.0f));
-					}
-					else
-					{
-						VectorSubtract(r_newrefdef.vieworg, v, vAngle);
-						VectorNormalize(vAngle);
-
-						if (vAngle[2] > 0.55f)
-							vAngle[2] = 0.55f;
-
-						qglColor4f(1, 1, 1, 0.9f - (vAngle[2] * 1.0f));
-					}
-				}
-
-				qglVertex3f(v[0], v[1], v[2]);
+				qglVertex3fv (nv);
 			}
-
-			qglEnd (); 
-  		}
-
-		R_ClearReflMatrix();
-
-		if (!gl_state.blend)
-			qglDisable(GL_BLEND);
-
-		if (gl_state.fragment_program) // jitwater
-			qglDisable(GL_FRAGMENT_PROGRAM_ARB);
-    }
+			else
+				qglVertex3fv (v);
+		}
+		qglEnd ();
+	}
 }
-// jitwater ===
 
 vec3_t	skyclip[6] = {
 	{1,1,0},
@@ -828,14 +648,14 @@ void R_ClearSkyBox (void)
 }
 
 
-void MakeSkyVec (float s, float t, int axis)
+void MakeSkyVec (float s, float t, int axis, float *tex_s, float *tex_t, float *vec, float size)
 {
 	vec3_t		v, b;
 	int			j, k;
 
-	b[0] = s*3300; //JKD - 9/24/02 this was at 2300 across the board, 3300 fixes 
-	b[1] = t*3300; // problems with skyboxes being too small for the large 
-	b[2] = 3300;   // outdoor, city levels.
+	b[0] = s * size; 
+	b[1] = t * size; 
+	b[2] = size;  
 
 	for (j=0 ; j<3 ; j++)
 	{
@@ -860,8 +680,10 @@ void MakeSkyVec (float s, float t, int axis)
 		t = sky_max;
 
 	t = 1.0 - t;
-	qglTexCoord2f (s, t);
-	qglVertex3fv (v);
+
+	*tex_s = s;
+	*tex_t = t;
+	VectorCopy(v, vec);
 }
 
 /*
@@ -869,10 +691,16 @@ void MakeSkyVec (float s, float t, int axis)
 R_DrawSkyBox
 ==============
 */
+extern  void GL_BlendFunction (GLenum sfactor, GLenum dfactor);
 int	skytexorder[6] = {0,2,1,3,4,5};
 void R_DrawSkyBox (void)
 {
 	int		i;
+	float	s ,t;
+	vec3_t	point;
+	float	alpha;
+	rscript_t *rs = NULL;
+	rs_stage_t *stage = NULL;
 
 	if (skyrotate)
 	{	// check for no sky at all
@@ -905,13 +733,132 @@ void R_DrawSkyBox (void)
 		GL_Bind (sky_images[skytexorder[i]]->texnum);
 
 		qglBegin (GL_QUADS);
-		MakeSkyVec (skymins[0][i], skymins[1][i], i);
-		MakeSkyVec (skymins[0][i], skymaxs[1][i], i);
-		MakeSkyVec (skymaxs[0][i], skymaxs[1][i], i);
-		MakeSkyVec (skymaxs[0][i], skymins[1][i], i);
+
+		MakeSkyVec (skymins[0][i], skymins[1][i], i, &s, &t, point, 3300);
+		qglTexCoord2f (s, t);
+		qglVertex3fv (point);
+
+		MakeSkyVec (skymins[0][i], skymaxs[1][i], i, &s, &t, point, 3300);
+		qglTexCoord2f (s, t);
+		qglVertex3fv (point);
+
+		MakeSkyVec (skymaxs[0][i], skymaxs[1][i], i, &s, &t, point, 3300);
+		qglTexCoord2f (s, t);
+		qglVertex3fv (point);
+
+		MakeSkyVec (skymaxs[0][i], skymins[1][i], i, &s, &t, point, 3300);
+		qglTexCoord2f (s, t);
+		qglVertex3fv (point);
+
 		qglEnd ();
+
 	}
 	qglPopMatrix ();
+
+    if(r_shaders->value) { //just cloud layers for now, we can expand this
+
+		qglPushMatrix (); //rotate the clouds
+		qglTranslatef (r_origin[0], r_origin[1], r_origin[2]);
+		qglRotatef (rs_realtime * 20, 0, 1, 0);
+
+		for (i=0 ; i<6 ; i++)
+		{
+			rs=(rscript_t *)sky_images[skytexorder[i]]->script;
+
+			if(rs) {	
+				
+				stage=rs->stage;
+				while (stage) 
+				{
+					qglDepthMask( GL_FALSE );	 	// no z buffering
+					qglEnable( GL_BLEND);
+					GL_TexEnv( GL_MODULATE );
+					GLSTATE_DISABLE_ALPHATEST
+
+					GL_Bind (stage->texture->texnum);
+
+					if (stage->blendfunc.blend) 
+					{
+						GL_BlendFunction(stage->blendfunc.source,stage->blendfunc.dest);
+						GLSTATE_ENABLE_BLEND
+					} 
+					else 
+					{
+						GLSTATE_DISABLE_BLEND
+					}
+
+					if (stage->alphashift.min || stage->alphashift.speed) 
+					{
+						alpha=0.0f;
+
+						if (!stage->alphashift.speed && stage->alphashift.min > 0) 
+						{
+							alpha=stage->alphashift.min;
+						} 
+						else if (stage->alphashift.speed) 
+						{
+							alpha=sin(rs_realtime * stage->alphashift.speed);
+							alpha=(alpha+1)*0.5f;
+							if (alpha > stage->alphashift.max) alpha=stage->alphashift.max;
+							if (alpha < stage->alphashift.min) alpha=stage->alphashift.min;
+						}
+					} 
+					else
+						alpha=1.0f;
+
+					qglColor4f(1,1,1,alpha);
+
+					if (stage->alphamask) 
+					{
+						GLSTATE_ENABLE_ALPHATEST
+					} 
+					else 
+					{
+						GLSTATE_DISABLE_ALPHATEST
+					}
+
+					skymins[0][i] = -1;
+					skymins[1][i] = -1;
+					skymaxs[0][i] = 1;
+					skymaxs[1][i] = 1;
+
+					qglBegin (GL_QUADS);
+
+					MakeSkyVec (skymins[0][i], skymins[1][i], i, &s, &t, point, 2300);
+					RS_SetTexcoords2D (stage, &s, &t);
+					qglTexCoord2f (s, t);
+					qglVertex3fv (point);
+
+					MakeSkyVec (skymins[0][i], skymaxs[1][i], i, &s, &t, point, 2300);
+					RS_SetTexcoords2D (stage, &s, &t);
+					qglTexCoord2f (s, t);
+					qglVertex3fv (point);
+
+					MakeSkyVec (skymaxs[0][i], skymaxs[1][i], i, &s, &t, point, 2300);
+					RS_SetTexcoords2D (stage, &s, &t);
+					qglTexCoord2f (s, t);
+					qglVertex3fv (point);
+
+					MakeSkyVec (skymaxs[0][i], skymins[1][i], i, &s, &t, point, 2300);
+					RS_SetTexcoords2D (stage, &s, &t);
+					qglTexCoord2f (s, t);
+					qglVertex3fv (point);
+
+					qglEnd();
+		
+					stage=stage->next;
+				}
+			}		
+		}
+		// restore the original blend mode
+		GLSTATE_DISABLE_ALPHATEST
+		GLSTATE_DISABLE_BLEND
+		qglBlendFunc ( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA );
+		qglColor4f( 1,1,1,1 );
+		qglDepthMask( GL_TRUE );	// back to normal Z buffering
+		GL_TexEnv( GL_REPLACE );
+		qglPopMatrix ();
+	}
 }
 
 
@@ -945,6 +892,32 @@ void R_SetSky (char *name, float rotate, vec3_t axis)
 		sky_images[i] = GL_FindImage (pathname, it_sky);
 		if (!sky_images[i])
 			sky_images[i] = r_notexture;
+		else { //valid sky, load shader
+			if (r_shaders->value) {
+				strcpy(pathname,sky_images[i]->name);
+				pathname[strlen(pathname)-4]=0;
+				sky_images[i]->script = RS_FindScript(pathname);
+				if(sky_images[i]->script)
+					RS_ReadyScript(sky_images[i]->script);
+			} 
+		}
+
+		if (strstr(pathname, "space")) {
+			VectorSet(sun_origin, -5000, -100000, 115000);
+			spacebox = true;
+		}
+		else if (strstr(pathname, "sea")) {
+			VectorSet(sun_origin, 140000, -80000, 125000);
+			spacebox = false;
+		}
+		else if (strstr(pathname, "hell")) {
+			VectorSet(sun_origin, 140000, 160000, 85000);
+			spacebox = false;
+		}
+		else {
+			VectorSet(sun_origin, 140000, -80000, 45000);
+			spacebox = false;
+		}
 
 		if (gl_skymip->value || skyrotate)
 		{	// take less memory
