@@ -161,6 +161,7 @@ void SV_SpawnServer (char *server, char *spawnpoint, server_state_t serverstate,
 	}
 
 	SZ_Init (&sv.multicast, sv.multicast_buf, sizeof(sv.multicast_buf));
+	SZ_SetName (&sv.multicast, "Server multicast buffer", true);
 
 	strcpy (sv.name, server);
 
@@ -229,6 +230,9 @@ void SV_SpawnServer (char *server, char *spawnpoint, server_state_t serverstate,
 	// set serverinfo variable
 	Cvar_FullSet ("mapname", sv.name, CVAR_SERVERINFO | CVAR_NOSET);
 
+	//get number of bots for bot kicking threshold cases
+	sv_numbots = ge->ACESP_FindBotNum();
+
 	Com_Printf ("-------------------------------------\n");
 }
 
@@ -243,7 +247,6 @@ void SV_InitGame (void)
 {
 	int		i;
 	edict_t	*ent;
-	char	idmaster[32];
 
 	if (svs.initialized)
 	{
@@ -279,7 +282,7 @@ void SV_InitGame (void)
 	// init clients
 	if (Cvar_VariableValue ("deathmatch") || Cvar_VariableValue ("ctf"))
 	{
-		if (maxclients->value <= 1)
+		if (maxclients->value <= 0)
 			Cvar_FullSet ("maxclients", "8", CVAR_SERVERINFO | CVAR_LATCH);
 		else if (maxclients->value > MAX_CLIENTS)
 			Cvar_FullSet ("maxclients", va("%i", MAX_CLIENTS), CVAR_SERVERINFO | CVAR_LATCH);
@@ -296,12 +299,6 @@ void SV_InitGame (void)
 	// heartbeats will always be sent to the COR master
 	svs.last_heartbeat = -999999;		// send immediately
 
-	sv_master = Cvar_Get ("cl_master", "master.corservers.com", CVAR_ARCHIVE);
-
-	Com_sprintf(idmaster, sizeof(idmaster), "%s:%i", sv_master->string, PORT_MASTER);
-
-	NET_StringToAdr (idmaster, &master_adr[0]);
-
 	// init game
 	SV_InitGameProgs ();
 	for (i=0 ; i<maxclients->value ; i++)
