@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "server.h"
 
-netadr_t	master_adr[MAX_MASTERS];	// address of group servers
+master_sv_t	master_status[MAX_MASTERS];	// status of master servers
 
 client_t	*sv_client;			// current client
 
@@ -35,14 +35,14 @@ cvar_t	*zombietime;			// seconds to sink messages after disconnect
 cvar_t	*rcon_password;			// password for remote server commands
 
 cvar_t	*allow_download;
-cvar_t *allow_download_players;
-cvar_t *allow_download_models;
-cvar_t *allow_download_sounds;
-cvar_t *allow_download_maps;
+cvar_t	*allow_download_players;
+cvar_t	*allow_download_models;
+cvar_t	*allow_download_sounds;
+cvar_t	*allow_download_maps;
 
-cvar_t *sv_airaccelerate;
+cvar_t	*sv_airaccelerate;
 
-cvar_t *sv_joustmode;
+cvar_t	*sv_joustmode;
 
 cvar_t	*sv_noreload;			// don't reload level state when reentering
 
@@ -57,7 +57,9 @@ cvar_t	*sv_reconnect_limit;	// minimum seconds between connect messages
 cvar_t	*sv_ratelimit_status;   //new security measures
 cvar_t	*sv_iplimit;
 
-cvar_t *sv_downloadurl;
+cvar_t	*sv_downloadurl;
+
+int		sv_numbots;
 
 void Master_Shutdown (void);
 
@@ -119,7 +121,10 @@ char	*SV_StatusString (void)
 {
 	char	player[1024];
 	static char	status[MAX_MSGLEN - 16];
-	int		i, j, k;
+	int		i;
+#ifdef NOTUSED
+	int j, k;
+#endif
 	client_t	*cl;
 	int		statusLength;
 	int		playerLength;
@@ -136,7 +141,9 @@ char	*SV_StatusString (void)
 		cl = &svs.clients[i];
 		if (cl->state == cs_connected || cl->state == cs_spawned )
 		{
-			name = cl->name; //handle color chars
+			name = cl->name; 
+#ifdef NOTUSED
+			//handle color chars
 			nametxt[0] = 0;
 			k = 0;
 			while(j = *name) {
@@ -152,6 +159,11 @@ char	*SV_StatusString (void)
 					break;
 			}
 			nametxt[k]=0;
+#else		
+			//allow color chars to be sent
+			strcpy(nametxt, name);
+			nametxt[31] = '\0'; //failsafe
+#endif
 			//s = NET_AdrToString ( cl->netchan.remote_address); //fuck you Luigi
 			Com_sprintf (player, sizeof(player), "%i %i \"%s\" \"127.0.0.1\"\n",
 				cl->edict->client->ps.stats[STAT_FRAGS], cl->ping, nametxt);
@@ -168,7 +180,9 @@ char	*SV_StatusString (void)
 	if(cl->edict->client->ps.botnum) {
 		for(i = 0; i < cl->edict->client->ps.botnum; i++) {
 
-			name = cl->edict->client->ps.bots[i].name; //handle color chars
+			name = cl->edict->client->ps.bots[i].name; 
+#ifdef NOTUSED
+			//handle color chars
 			nametxt[0] = 0;
 			k = 0;
 			while(j = *name) {
@@ -184,6 +198,11 @@ char	*SV_StatusString (void)
 					break;
 			}
 			nametxt[k]=0;
+#else
+			//allow color chars to be sent
+			strcpy(nametxt, name);
+			nametxt[31] = '\0'; //failsafe
+#endif
 
 			Com_sprintf (player, sizeof(player), "%i %i \"%s\" \"127.0.0.1\"\n",
 				cl->edict->client->ps.bots[i].score, 0, nametxt);
@@ -275,7 +294,18 @@ SVC_Ack
 */
 void SVC_Ack (void)
 {
+	int		i;
 	Com_Printf ("Ping acknowledge from %s\n", NET_AdrToString(net_from));
+	for ( i = 0 ; i < MAX_MASTERS ; i ++ ) {
+		if ( master_status[i].name[0] == 0 )
+			break;
+
+		if ( master_status[i].addr.port == 0 )
+			continue;
+
+		if ( NET_CompareAdr (master_status[i].addr, net_from) )
+			master_status[i].last_ping_ack = 2;
+	}
 }
 
 /*
@@ -409,7 +439,7 @@ void SVC_DirectConnect (void)
 	int			qport;
 	int			challenge;
 	int			previousclients;
-	int			botnum;
+	int			botnum, botkick;
 
 	adr = net_from;
 
@@ -557,11 +587,23 @@ void SVC_DirectConnect (void)
 	}
 
 	// find a client slot
-	cl = &svs.clients[0]; //get the bots info from the first client
+	cl = &svs.clients[0]; //get the active bots info from the first client
 	botnum = cl->edict->client->ps.botnum;
 	//still need to reserve one slot
 	newcl = NULL;
 
+	//are we using botkickthreshold?
+	botkick = Cvar_VariableValue("sv_botkickthreshold");
+
+	//prevent client slot overwrites with bots rejoining after map change
+	if(botkick) {
+		
+		if(botkick < sv_numbots)
+			botnum = botkick;
+		else
+			botnum = sv_numbots;
+	}
+
 	for (i=0,cl=svs.clients ; i<maxclients->value-botnum; i++,cl++)
 	{
 		if (cl->state == cs_free)
@@ -614,6 +656,8 @@ gotnewcl:
 	newcl->state = cs_connected;
 
 	SZ_Init (&newcl->datagram, newcl->datagram_buf, sizeof(newcl->datagram_buf) );
+	SZ_SetName (&newcl->datagram, va("Datagram buffer %s", NET_AdrToString(adr)), true);
+
 	newcl->datagram.allowoverflow = true;
 	newcl->lastmessage = svs.realtime;	// don't timeout
 	newcl->lastconnect = svs.realtime;
@@ -1056,8 +1100,7 @@ let it know we are alive, and log information
 #define	HEARTBEAT_SECONDS	300
 void Master_Heartbeat (void)
 {
-	char		*string;
-	int			i;
+	char		string[MAX_MSGLEN];
 
 	// pgm post3.19 change, cvar pointer not validated before dereferencing
 
@@ -1074,30 +1117,8 @@ void Master_Heartbeat (void)
 	svs.last_heartbeat = svs.realtime;
 
 	// send the same string that we would give for a status OOB command
-	string = SV_StatusString();
-
-	// send to group master
-	if(dedicated || dedicated->value) {
-		for (i=0 ; i<MAX_MASTERS ; i++)
-			if (master_adr[i].port)
-			{
-				Com_Printf ("Sending heartbeat to %s\n", NET_AdrToString (master_adr[i]));
-				Netchan_OutOfBandPrint (NS_SERVER, master_adr[i], "heartbeat\n%s", string);
-			}
-	}
-	else {
-
-		sv_master = Cvar_Get ("cl_master", "master.corservers.com", CVAR_ARCHIVE);
-		if (!NET_StringToAdr (sv_master->string, &master_adr[0]))
-
-		{
-			Com_Printf ("Bad Master IP");
-		}
-		if (master_adr[0].port == 0)
-			master_adr[0].port = BigShort (PORT_MASTER);
-		Com_Printf ("Sending heartbeat to %s\n", NET_AdrToString (master_adr[0]));
-		Netchan_OutOfBandPrint (NS_SERVER, master_adr[0], "heartbeat\n%s", string);
-	}
+	Com_sprintf (string, MAX_MSGLEN, "heartbeat\n%s", SV_StatusString ());
+	SV_HandleMasters (string, "heartbeat");
 }
 
 /*
@@ -1109,36 +1130,111 @@ Informs all masters that this server is going down
 */
 void Master_Shutdown (void)
 {
-	int			i;
 
 	// pgm post3.19 change, cvar pointer not validated before dereferencing
 	if (!public_server || !public_server->value)
 		return;		// a private dedicated game
 
-	// send to group master
-	if(dedicated || dedicated->value) {
-		for (i=0 ; i<MAX_MASTERS ; i++)
-			if (master_adr[i].port)
-			{
-				if (i > 0)
-					Com_Printf ("Sending heartbeat to %s\n", NET_AdrToString (master_adr[i]));
-				Netchan_OutOfBandPrint (NS_SERVER, master_adr[i], "shutdown");
-			}
-	}
-	else {
+	SV_HandleMasters ("shutdown", "shutdown");
+}
 
-		sv_master = Cvar_Get ("cl_master", "master.corservers.com", CVAR_ARCHIVE);
-		if (!NET_StringToAdr (sv_master->string, &master_adr[0]))
+
+/*
+=================
+SV_HandleMasters
+
+Sends a message to all master servers, looking up the
+master servers' addresses if appropriate.
+=================
+*/
+void SV_HandleMasters (const char *message, const char *console_message)
+{
+	int		i;
+	qboolean	updated_master;
+
+	// if the server is not dedicated, we need to check cl_master
+	if ( !( dedicated && dedicated->value ) )
+	{
+		if ( !sv_master )
 		{
-			Com_Printf ("Bad Master IP");
+			sv_master = Cvar_Get ("cl_master", "master.corservers.com", CVAR_ARCHIVE);
+			updated_master = true;
 		}
-		if (master_adr[0].port == 0)
-			master_adr[0].port = BigShort (PORT_MASTER);
-		Com_Printf ("Sending heartbeat to %s\n", NET_AdrToString (master_adr[0]));
-		Netchan_OutOfBandPrint (NS_SERVER, master_adr[0], "shutdown");
+		else if ( sv_master->modified )
+		{
+			sv_master->modified = false;
+			updated_master = true;
+		}
+		else
+		{
+			updated_master = false;
+		}
+
+		if ( updated_master )
+		{
+			memset (&master_status[0], 0, sizeof(master_sv_t));
+			strncpy (master_status[0].name, sv_master->string, MAX_MASTER_LEN);
+		}
+	}
+
+	// first we need to loop through the master servers
+	// in order to find the ones that need (re-)resolving
+	for ( i = 0; i < MAX_MASTERS ; i ++ )
+	{
+		if ( master_status[i].name[0] == 0 )
+			break;
+
+		// if we already sent a ping and didn't get
+		// any acknowledgement packet, we need to try
+		// re-resolving
+		if ( master_status[i].resolved && master_status[i].last_ping_sent > master_status[i].last_ping_ack )
+		{
+			Com_Printf ("No acknowledgement from %s - re-resolving\n", master_status[i].name);
+			master_status[i].resolved = false;
+		}
+
+		if ( master_status[i].resolved )
+			continue;
+
+		if (!NET_StringToAdr (master_status[i].name, &master_status[i].addr))
+		{
+			// resolution failed, did we say so already?
+			if ( !master_status[i].failed )
+			{
+				Com_Printf ("Bad master address: %s\n", master_status[i].name);
+				master_status[i].failed = true;
+			}
+			master_status[i].addr.port = 0;
+		}
+		else
+		{
+			master_status[i].failed = false;
+			master_status[i].resolved = true;
+
+			if (master_status[i].addr.port == 0)
+				master_status[i].addr.port = BigShort (PORT_MASTER);
+
+			Com_Printf ("Master server at %s\n", NET_AdrToString (master_status[i].addr));
+		}
+	}
+
+	// send the message we needed to send
+	for ( i = 0 ; i < MAX_MASTERS ; i ++ )
+	{
+		if ( master_status[i].name[0] == 0 )
+			break;
+
+		if ( master_status[i].addr.port == 0 )
+			continue;
+
+		Com_Printf ("Sending %s to %s\n", console_message, NET_AdrToString (master_status[i].addr));
+		Netchan_OutOfBandPrint (NS_SERVER, master_status[i].addr, "%s", message);
+		master_status[i].last_ping_sent = 1;
+		master_status[i].last_ping_ack = 0;
 	}
 }
 
+
 //============================================================================
 
 
@@ -1240,6 +1336,7 @@ void SV_Init (void)
 	sv_iplimit = Cvar_Get ("sv_iplimit", "3", 0);
 
 	SZ_Init (&net_message, net_message_buffer, sizeof(net_message_buffer));
+	SZ_SetName (&net_message, "Net message buffer", true);
 }
 
 /*
