@@ -72,17 +72,16 @@ typedef struct vidmode_s
 
 vidmode_t vid_modes[] =
 {
-	{ "Mode 0: 640x480",   640, 480,   0 },
-	{ "Mode 1: 640x480",   640, 480,   1 },
-	{ "Mode 2: 640x480",   640, 480,   2 },
-	{ "Mode 3: 640x480",   640, 480,   3 },
-	{ "Mode 4: 800x600",   800, 600,   4 },
-	{ "Mode 5: 960x720",   960, 720,   5 },
-	{ "Mode 6: 1024x768",  1024, 768,  6 },
-	{ "Mode 7: 1152x864",  1152, 864,  7 },
-	{ "Mode 8: 1280x960",  1280, 960, 8 },
-	{ "Mode 9: 1600x1200", 1600, 1200, 9 },
-	{ "Mode 10: 2048x1536", 2048, 1536, 10 }
+    { "Mode 0: 640x480",   640, 480,   0 },
+    { "Mode 1: 800x600",   800, 600,   1 },
+    { "Mode 2: 960x720",   960, 720,   2 },
+    { "Mode 3: 1024x768",  1024, 768,  3 },
+    { "Mode 4: 1152x864",  1152, 864,  4 },
+    { "Mode 5: 1280x960",  1280, 960, 5 },
+	{ "Mode 6: 1360x768",  1360, 768, 6 },
+    { "Mode 7: 1600x1200", 1600, 1200, 7 },
+	{ "Mode 8: 1680x1050", 1680, 1050, 8 },
+	{ "Mode 9: 2048x1536", 2048, 1536, 9 }
 };
 
 static int s_numVidModes = ( sizeof(vid_modes) / sizeof(vid_modes[0]));
@@ -186,11 +185,7 @@ VID_Init
 void VID_Init (void)
 {
 	/* Create the video variables so we know how to start the graphics drivers */
-	// if DISPLAY is defined, try X
-	if (getenv("DISPLAY"))
-		vid_ref = Cvar_Get ("vid_ref", "glx", CVAR_ARCHIVE);
-	else
-		vid_ref = Cvar_Get ("vid_ref", "glx", CVAR_ARCHIVE);
+	vid_ref = Cvar_Get ("vid_ref", "glx", CVAR_ARCHIVE);
 	vid_xpos = Cvar_Get ("vid_xpos", "3", CVAR_ARCHIVE);
 	vid_ypos = Cvar_Get ("vid_ypos", "22", CVAR_ARCHIVE);
 	vid_fullscreen = Cvar_Get ("vid_fullscreen", "0", CVAR_ARCHIVE);
